@@ -22,6 +22,8 @@ urlparse_local.uses_netloc.extend(['bk', 'ssh', 'svn'])
 
 class Package:
 
+  packages = []    # list of packages processed and added so far
+
   def __init__(self,argdb,log):
     self.installable     = False  # an already installed package can be picked --with-xxx-dir
     self.downloadable    = False  # package can be downloaded and installed with --download-xxx
@@ -131,6 +133,7 @@ class Package:
         self.log.write('Version number for '+name+' is '+self.iversion)
       except AttributeError:
         pass
+      if self.havepackage: Package.packages.append(self)
     else: # not requested
       if hasattr(self,'SkipInstall'):
         self.SkipInstall(slepcrules)
@@ -153,6 +156,12 @@ class Package:
     if self.downloadpackage and self.fortran and not hasattr(petsc,'fc'):
       self.log.Exit('Option --download-'+self.packagename+' requires a Fortran compiler')
 
+  def Require(self,packagename):
+    for p in Package.packages:
+      if p.packagename.upper() == packagename.upper():
+        return p
+    self.log.Exit('The package '+self.packagename.upper()+' requires configuring also with '+packagename.upper()+". Run configure --help for details on how to install it")
+
   def DistilLibList(self,packagelibs,petsc):
     libs = []
     for l in packagelibs.split():
@@ -298,7 +307,7 @@ Downloaded package %s from: %s is not a tarball.
     try:
       # check if 'dirname' is set'
       if dirname:
-        (result,output) = self.RunCommand('cd '+externdir+'; chmod -R a+r '+dirname+'; find '+dirname+' -type d -name "*" -exec chmod a+rx {} \;')
+        (result,output) = self.RunCommand('cd '+externdir+'; chmod -R a+r '+dirname+'; find '+dirname+r' -type d -name "*" -exec chmod a+rx {} \;')
         if dirname != self.GetDirectoryName():
           self.log.write('The directory name '+dirname+' is different from the expected one, renaming to '+self.GetDirectoryName())
           os.rename(os.path.join(externdir,dirname),os.path.join(externdir,self.GetDirectoryName()))
@@ -357,15 +366,14 @@ Downloaded package %s from: %s is not a tarball.
       self.log.Exit('Cannot create temporary directory')
     try:
       with open(os.path.join(tmpdir,'makefile'),'w') as makefile:
-        if cflags!='':
-          if clanguage=='c++': makefile.write('CXXFLAGS='+cflags+'\n')
-          else: makefile.write('CFLAGS='+cflags+'\n')
         makefile.write('checklink: checklink.o\n')
         makefile.write('\t${CLINKER} -o checklink checklink.o ${LINKFLAGS} ${PETSC_SNES_LIB}\n')
         makefile.write('\t@${RM} -f checklink checklink.o\n')
-        makefile.write('LOCDIR = ./\n')
         makefile.write('include '+os.path.join('${PETSC_DIR}','lib','petsc','conf','variables')+'\n')
         makefile.write('include '+os.path.join('${PETSC_DIR}','lib','petsc','conf','rules')+'\n')
+        if cflags:
+          if clanguage=='c++': makefile.write('CXXFLAGS='+cflags+'\n')
+          else: makefile.write('CFLAGS='+cflags+'\n')
     except:
       self.log.Exit('Cannot create makefile in temporary directory')
 
@@ -379,11 +387,12 @@ Downloaded package %s from: %s is not a tarball.
         code += 'int '+ c + '() { return 0; } \n'
 
       code += 'int main() {\n'
-      code += 'Vec v; Mat m; KSP k;\n'
-      code += 'PetscInitializeNoArguments();\n'
-      code += 'VecCreate(PETSC_COMM_WORLD,&v);\n'
-      code += 'MatCreate(PETSC_COMM_WORLD,&m);\n'
-      code += 'KSPCreate(PETSC_COMM_WORLD,&k);\n'
+      code += 'PetscErrorCode ierr; Vec v; Mat m; KSP k;\n'
+      code += 'ierr = PetscInitializeNoArguments();\n'
+      code += 'ierr = VecCreate(PETSC_COMM_WORLD,&v);\n'
+      code += 'ierr = MatCreate(PETSC_COMM_WORLD,&m);\n'
+      code += 'ierr = KSPCreate(PETSC_COMM_WORLD,&k);\n'
+      code += '(void)ierr;\n'
       for f in functions:
         code += f + '();\n'
       code += 'return 0;\n}\n'
@@ -481,9 +490,11 @@ Downloaded package %s from: %s is not a tarball.
       self.log.Exit('Unable to link with '+name+' library in directories '+' '.join(dirs)+' with libraries and link flags '+flags)
 
     slepcconf.write('#define SLEPC_HAVE_' + name + ' 1\n#define SLEPC_' + name + '_HAVE_'+mangling+' 1\n')
-    slepcvars.write(name + '_LIB = '+flags+'\n')
+    if not hasattr(self,'petscdepend'):
+      slepcvars.write(name + '_LIB = '+flags+'\n')
+      self.libflags = flags
+      self.packageflags = flags
     self.havepackage = True
-    self.packageflags = flags
 
   def WriteMakefile(self,fname,builddir,cont):
     self.log.write('Using makefile:\n')
