@@ -18,8 +18,8 @@ class Arpack(package.Package):
     self.packagetype    = 'cmake'
     self.installable    = True
     self.downloadable   = True
-    #self.version        = '3.8.0'
-    self.gitcommit      = '5131f792f289c4e63b4cb1f56003e59507910132'
+    self.version        = '3.9.0'
+    #self.gitcommit      = '5131f792f289c4e63b4cb1f56003e59507910132'
     obj = self.version if hasattr(self,'version') else self.gitcommit
     self.url            = 'https://github.com/opencollab/arpack-ng/archive/'+obj+'.tar.gz'
     self.archive        = 'arpack-ng-'+obj+'.tar.gz'
@@ -88,18 +88,18 @@ class Arpack(package.Package):
 
     if hasattr(petsc,'cmake'): # Build with cmake
       builddir = slepc.CreateDir(builddir,'build')
-      confopt = ['-DCMAKE_INSTALL_PREFIX='+prefixdir, '-DCMAKE_C_COMPILER="'+petsc.cc+'"', '-DCMAKE_C_FLAGS:STRING="'+petsc.getCFlags()+'"', '-DCMAKE_Fortran_COMPILER="'+petsc.fc+'"', '-DCMAKE_Fortran_FLAGS:STRING="'+petsc.getFFlags()+'"', '-DBLAS_LIBRARIES="'+petsc.blaslapack_lib+'"']
+      confopt = ['-DCMAKE_INSTALL_PREFIX='+prefixdir, '-DCMAKE_INSTALL_NAME_DIR:STRING="'+os.path.join(prefixdir,'lib')+'"', '-DCMAKE_INSTALL_LIBDIR:STRING="lib"', '-DCMAKE_C_COMPILER="'+petsc.cc+'"', '-DCMAKE_C_FLAGS:STRING="'+petsc.getCFlags()+'"', '-DCMAKE_Fortran_COMPILER="'+petsc.fc+'"', '-DCMAKE_Fortran_FLAGS:STRING="'+petsc.getFFlags()+'"', '-DBLAS_LIBRARIES="'+petsc.blaslapack_lib+'"']
       if not petsc.mpiuni and not petsc.msmpi:
         confopt = confopt + ['-DMPI=ON', '-DMPI_C_COMPILER="'+petsc.cc+'"', '-DMPI_Fortran_COMPILER="'+petsc.fc+'"']
-      confopt = confopt + ['-DCMAKE_BUILD_TYPE='+ ('Debug' if petsc.debug else 'Release')]
+      confopt.append('-DCMAKE_BUILD_TYPE='+('Debug' if petsc.debug else 'Release'))
       if petsc.buildsharedlib:
         confopt = confopt + ['-DBUILD_SHARED_LIBS=ON', '-DCMAKE_INSTALL_RPATH:PATH='+os.path.join(prefixdir,'lib')]
       else:
-        confopt = confopt + ['-DBUILD_SHARED_LIBS=OFF']
+        confopt.append('-DBUILD_SHARED_LIBS=OFF')
       if petsc.ind64:
-        confopt = confopt + ['-DINTERFACE64=1']
+        confopt.append('-DINTERFACE64=1')
       if 'MSYSTEM' in os.environ:
-        confopt = confopt + ['-G "MSYS Makefiles"']
+        confopt.append('-G "MSYS Makefiles"')
       (result,output) = self.RunCommand('cd '+builddir+' && '+petsc.cmake+' '+' '.join(confopt)+' '+self.buildflags+' .. && '+petsc.make+' -j'+petsc.make_np+' && '+petsc.make+' install')
 
     else: # Build with autoreconf
@@ -108,13 +108,13 @@ class Arpack(package.Package):
         self.log.Exit('--download-arpack requires that the command autoreconf is available on your PATH, or alternatively that PETSc has been configured with CMake')
       if self.buildflags:
         self.log.Exit('You specified --download-arpack-cmake-arguments but ARPACK will be built with autoreconf because PETSc was not configured with CMake')
-      confopt = ['--prefix='+prefixdir, 'CC="'+petsc.cc+'"', 'CFLAGS="'+petsc.getCFlags()+'"', 'F77="'+petsc.fc+'"', 'FFLAGS="'+petsc.getFFlags()+'"', 'FC="'+petsc.fc+'"', 'FCFLAGS="'+petsc.getFFlags()+'"', 'LIBS="'+petsc.blaslapack_lib+'"']
+      confopt = ['--prefix='+prefixdir, '--libdir='+os.path.join(prefixdir,'lib'), 'CC="'+petsc.cc+'"', 'CFLAGS="'+petsc.getCFlags()+'"', 'F77="'+petsc.fc+'"', 'FFLAGS="'+petsc.getFFlags()+'"', 'FC="'+petsc.fc+'"', 'FCFLAGS="'+petsc.getFFlags()+'"', 'LIBS="'+petsc.blaslapack_lib+'"']
       if not petsc.mpiuni and not petsc.msmpi:
         confopt = confopt + ['--enable-mpi MPICC="'+petsc.cc+'"', 'MPIF77="'+petsc.fc+'"', 'MPIFC="'+petsc.fc+'"']
       if not petsc.buildsharedlib:
-        confopt = confopt + ['--disable-shared']
+        confopt.append('--disable-shared')
       if petsc.ind64:
-        confopt = confopt + ['INTERFACE64=1']
+        confopt.append('INTERFACE64=1')
       (result,output) = self.RunCommand('cd '+builddir+'&& sh bootstrap && ./configure '+' '.join(confopt)+' && '+petsc.make+' -j'+petsc.make_np+' && '+petsc.make+' install')
 
     if result:
