@@ -14,7 +14,7 @@
 #include <slepc/private/epsimpl.h>
 #include "arpack.h"
 
-PetscErrorCode EPSSetUp_ARPACK(EPS eps)
+static PetscErrorCode EPSSetUp_ARPACK(EPS eps)
 {
   PetscInt       ncv;
   EPS_ARPACK     *ar = (EPS_ARPACK*)eps->data;
@@ -61,12 +61,12 @@ PetscErrorCode EPSSetUp_ARPACK(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode EPSSolve_ARPACK(EPS eps)
+static PetscErrorCode EPSSolve_ARPACK(EPS eps)
 {
   EPS_ARPACK     *ar = (EPS_ARPACK*)eps->data;
   char           bmat[1],howmny[] = "A";
   const char     *which;
-  PetscInt       n,iparam[11],ipntr[14],ido,info,nev,ncv,rvec;
+  PetscInt       n,ld,iparam[11],ipntr[14],ido,info,nev,ncv,rvec;
 #if !defined(PETSC_HAVE_MPIUNI) && !defined(PETSC_HAVE_MSMPI)
   MPI_Fint       fcomm;
 #endif
@@ -88,6 +88,7 @@ PetscErrorCode EPSSolve_ARPACK(EPS eps)
   PetscCall(EPSGetStartVector(eps,0,NULL));
   PetscCall(BVSetActiveColumns(eps->V,0,0));  /* just for deflation space */
   PetscCall(BVCopyVec(eps->V,0,eps->work[1]));
+  PetscCall(BVGetLeadingDimension(eps->V,&ld));
   PetscCall(BVGetArray(eps->V,&pV));
   PetscCall(VecGetArray(eps->work[1],&resid));
 
@@ -163,12 +164,12 @@ PetscErrorCode EPSSolve_ARPACK(EPS eps)
 
 #if !defined(PETSC_USE_COMPLEX)
     if (eps->ishermitian) {
-      PetscStackCallExternalVoid("ARPACKsaupd",ARPACKsaupd_(&fcomm,&ido,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&n,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
+      PetscStackCallExternalVoid("ARPACKsaupd",ARPACKsaupd_(&fcomm,&ido,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&ld,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
     } else {
-      PetscStackCallExternalVoid("ARPACKnaupd",ARPACKnaupd_(&fcomm,&ido,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&n,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
+      PetscStackCallExternalVoid("ARPACKnaupd",ARPACKnaupd_(&fcomm,&ido,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&ld,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
     }
 #else
-    PetscStackCallExternalVoid("ARPACKnaupd",ARPACKnaupd_(&fcomm,&ido,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&n,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,ar->rwork,&info));
+    PetscStackCallExternalVoid("ARPACKnaupd",ARPACKnaupd_(&fcomm,&ido,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&ld,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,ar->rwork,&info));
 #endif
 
     if (ido == -1 || ido == 1 || ido == 2) {
@@ -220,12 +221,12 @@ PetscErrorCode EPSSolve_ARPACK(EPS eps)
   if (eps->nconv > 0) {
 #if !defined(PETSC_USE_COMPLEX)
     if (eps->ishermitian) {
-      PetscStackCallExternalVoid("ARPACKseupd",ARPACKseupd_(&fcomm,&rvec,howmny,ar->select,eps->eigr,pV,&n,&sigmar,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&n,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
+      PetscStackCallExternalVoid("ARPACKseupd",ARPACKseupd_(&fcomm,&rvec,howmny,ar->select,eps->eigr,pV,&ld,&sigmar,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&ld,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
     } else {
-      PetscStackCallExternalVoid("ARPACKneupd",ARPACKneupd_(&fcomm,&rvec,howmny,ar->select,eps->eigr,eps->eigi,pV,&n,&sigmar,&sigmai,ar->workev,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&n,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
+      PetscStackCallExternalVoid("ARPACKneupd",ARPACKneupd_(&fcomm,&rvec,howmny,ar->select,eps->eigr,eps->eigi,pV,&ld,&sigmar,&sigmai,ar->workev,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&ld,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,&info));
     }
 #else
-    PetscStackCallExternalVoid("ARPACKneupd",ARPACKneupd_(&fcomm,&rvec,howmny,ar->select,eps->eigr,pV,&n,&sigmar,ar->workev,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&n,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,ar->rwork,&info));
+    PetscStackCallExternalVoid("ARPACKneupd",ARPACKneupd_(&fcomm,&rvec,howmny,ar->select,eps->eigr,pV,&ld,&sigmar,ar->workev,bmat,&n,which,&nev,&eps->tol,resid,&ncv,pV,&ld,iparam,ipntr,ar->workd,ar->workl,&ar->lworkl,ar->rwork,&info));
 #endif
     PetscCheck(info==0,PetscObjectComm((PetscObject)eps),PETSC_ERR_LIB,"Error reported by ARPACK subroutine xxEUPD (%" PetscInt_FMT ")",info);
   }
@@ -240,7 +241,7 @@ PetscErrorCode EPSSolve_ARPACK(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode EPSBackTransform_ARPACK(EPS eps)
+static PetscErrorCode EPSBackTransform_ARPACK(EPS eps)
 {
   PetscBool      isSinv;
 
@@ -250,7 +251,7 @@ PetscErrorCode EPSBackTransform_ARPACK(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode EPSReset_ARPACK(EPS eps)
+static PetscErrorCode EPSReset_ARPACK(EPS eps)
 {
   EPS_ARPACK     *ar = (EPS_ARPACK*)eps->data;
 
@@ -265,7 +266,7 @@ PetscErrorCode EPSReset_ARPACK(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode EPSDestroy_ARPACK(EPS eps)
+static PetscErrorCode EPSDestroy_ARPACK(EPS eps)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(eps->data));
