@@ -120,7 +120,7 @@ PetscErrorCode MFNGetOperator(MFN mfn,Mat *A)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mfn,MFN_CLASSID,1);
-  PetscValidPointer(A,2);
+  PetscAssertPointer(A,2);
   *A = mfn->A;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -158,7 +158,7 @@ PetscErrorCode MFNAllocateSolution(MFN mfn,PetscInt extra)
   /* allocate basis vectors */
   if (!mfn->V) PetscCall(MFNGetBV(mfn,&mfn->V));
   if (!oldsize) {
-    if (!((PetscObject)(mfn->V))->type_name) PetscCall(BVSetType(mfn->V,BVSVEC));
+    if (!((PetscObject)(mfn->V))->type_name) PetscCall(BVSetType(mfn->V,BVMAT));
     PetscCall(MatCreateVecsEmpty(mfn->A,&t,NULL));
     PetscCall(BVSetSizesFromVec(mfn->V,t,requested));
     PetscCall(VecDestroy(&t));
