@@ -1,7 +1,7 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -63,6 +63,10 @@
       PetscEnum, parameter :: NEP_ERROR_RELATIVE         =  1
       PetscEnum, parameter :: NEP_ERROR_BACKWARD         =  2
 
+      PetscEnum, parameter :: NEP_CISS_EXTRACTION_RITZ   =  0
+      PetscEnum, parameter :: NEP_CISS_EXTRACTION_HANKEL =  1
+      PetscEnum, parameter :: NEP_CISS_EXTRACTION_CAA    =  2
+
 !
 !   Possible arguments to NEPMonitorSet()
 !
@@ -72,3 +76,6 @@
 
       external NEPMonitorConvergedDestroy
 
+#if defined(_WIN32) && defined(PETSC_USE_SHARED_LIBRARIES)
+!DEC$ ATTRIBUTES DLLEXPORT::SLEPC_NULL_NEP
+#endif
