@@ -251,7 +251,7 @@ PetscErrorCode NEPSetInitialSpace(NEP nep,PetscInt n,Vec is[])
   PetscValidLogicalCollectiveInt(nep,n,2);
   PetscCheck(n>=0,PetscObjectComm((PetscObject)nep),PETSC_ERR_ARG_OUTOFRANGE,"Argument n cannot be negative");
   if (n>0) {
-    PetscValidPointer(is,3);
+    PetscAssertPointer(is,3);
     PetscValidHeaderSpecific(*is,VEC_CLASSID,3);
   }
   PetscCall(SlepcBasisReference_Private(n,is,&nep->nini,&nep->IS));
@@ -322,7 +322,7 @@ PetscErrorCode NEPAllocateSolution(NEP nep,PetscInt extra)
   /* allocate V */
   if (!nep->V) PetscCall(NEPGetBV(nep,&nep->V));
   if (!oldsize) {
-    if (!((PetscObject)(nep->V))->type_name) PetscCall(BVSetType(nep->V,BVSVEC));
+    if (!((PetscObject)(nep->V))->type_name) PetscCall(BVSetType(nep->V,BVMAT));
     if (nep->fui==NEP_USER_INTERFACE_SPLIT) T = nep->A[0];
     else PetscCall(NEPGetFunction(nep,&T,NULL,NULL,NULL));
     PetscCall(MatCreateVecsEmpty(T,&t,NULL));
