@@ -237,7 +237,7 @@ static PetscErrorCode Apply_Linear(ST st,Vec x,Vec y)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPSetUp_Linear(PEP pep)
+static PetscErrorCode PEPSetUp_Linear(PEP pep)
 {
   PEP_LINEAR     *ctx = (PEP_LINEAR*)pep->data;
   ST             st;
@@ -629,7 +629,7 @@ static PetscErrorCode PEPLinearExtract_Norm(PEP pep,EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPExtractVectors_Linear(PEP pep)
+static PetscErrorCode PEPExtractVectors_Linear(PEP pep)
 {
   PEP_LINEAR     *ctx = (PEP_LINEAR*)pep->data;
 
@@ -650,7 +650,7 @@ PetscErrorCode PEPExtractVectors_Linear(PEP pep)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPSolve_Linear(PEP pep)
+static PetscErrorCode PEPSolve_Linear(PEP pep)
 {
   PEP_LINEAR     *ctx = (PEP_LINEAR*)pep->data;
   PetscScalar    sigma;
@@ -697,7 +697,7 @@ static PetscErrorCode EPSMonitor_Linear(EPS eps,PetscInt its,PetscInt nconv,Pets
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPSetFromOptions_Linear(PEP pep,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode PEPSetFromOptions_Linear(PEP pep,PetscOptionItems *PetscOptionsObject)
 {
   PetscBool      set,val;
   PetscInt       k;
@@ -867,7 +867,7 @@ PetscErrorCode PEPLinearGetExplicitMatrix(PEP pep,PetscBool *explicitmat)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidBoolPointer(explicitmat,2);
+  PetscAssertPointer(explicitmat,2);
   PetscUseMethod(pep,"PEPLinearGetExplicitMatrix_C",(PEP,PetscBool*),(pep,explicitmat));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -946,12 +946,12 @@ PetscErrorCode PEPLinearGetEPS(PEP pep,EPS *eps)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidPointer(eps,2);
+  PetscAssertPointer(eps,2);
   PetscUseMethod(pep,"PEPLinearGetEPS_C",(PEP,EPS*),(pep,eps));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPView_Linear(PEP pep,PetscViewer viewer)
+static PetscErrorCode PEPView_Linear(PEP pep,PetscViewer viewer)
 {
   PEP_LINEAR     *ctx = (PEP_LINEAR*)pep->data;
   PetscBool      isascii;
@@ -969,7 +969,7 @@ PetscErrorCode PEPView_Linear(PEP pep,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPReset_Linear(PEP pep)
+static PetscErrorCode PEPReset_Linear(PEP pep)
 {
   PEP_LINEAR     *ctx = (PEP_LINEAR*)pep->data;
 
@@ -986,7 +986,7 @@ PetscErrorCode PEPReset_Linear(PEP pep)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode PEPDestroy_Linear(PEP pep)
+static PetscErrorCode PEPDestroy_Linear(PEP pep)
 {
   PEP_LINEAR     *ctx = (PEP_LINEAR*)pep->data;
 
