@@ -61,6 +61,10 @@ static PetscErrorCode MatDestroy_Cyclic(Mat B)
   PetscCall(VecDestroy(&ctx->x2));
   PetscCall(VecDestroy(&ctx->y1));
   PetscCall(VecDestroy(&ctx->y2));
+  if (ctx->misaligned) {
+    PetscCall(VecDestroy(&ctx->wx2));
+    PetscCall(VecDestroy(&ctx->wy2));
+  }
   PetscCall(PetscFree(ctx));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -78,6 +82,8 @@ static PetscErrorCode SVDCyclicGetCyclicMat(SVD svd,Mat A,Mat AT,Mat *C)
   Mat              Zm,Zn;
 #if defined(PETSC_HAVE_CUDA)
   PetscBool        cuda;
+  const PetscInt   *ranges;
+  PetscMPIInt      size;
 #endif
 
   PetscFunctionBegin;
@@ -123,6 +129,21 @@ static PetscErrorCode SVDCyclicGetCyclicMat(SVD svd,Mat A,Mat AT,Mat *C)
       PetscCall(MatShellSetOperation(*C,MATOP_MULT,(void(*)(void))MatMult_Cyclic));
     PetscCall(MatGetVecType(A,&vtype));
     PetscCall(MatSetVecType(*C,vtype));
+#if defined(PETSC_HAVE_CUDA)
+    if (cuda) {
+      /* check alignment of bottom block */
+      PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)ctx->x1),&size));
+      PetscCall(VecGetOwnershipRanges(ctx->x1,&ranges));
+      for (i=0;i<size;i++) {
+        ctx->misaligned = (((ranges[i+1]-ranges[i])*sizeof(PetscScalar))%16)? PETSC_TRUE: PETSC_FALSE;
+        if (ctx->misaligned) break;
+      }
+      if (ctx->misaligned) {  /* create work vectors for MatMult */
+        PetscCall(VecDuplicate(ctx->x2,&ctx->wx2));
+        PetscCall(VecDuplicate(ctx->y2,&ctx->wy2));
+      }
+    }
+#endif
   }
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -223,6 +244,10 @@ static PetscErrorCode MatDestroy_ECross(Mat B)
   PetscCall(VecDestroy(&ctx->y2));
   PetscCall(VecDestroy(&ctx->diag));
   PetscCall(VecDestroy(&ctx->w));
+  if (ctx->misaligned) {
+    PetscCall(VecDestroy(&ctx->wx2));
+    PetscCall(VecDestroy(&ctx->wy2));
+  }
   PetscCall(PetscFree(ctx));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -241,6 +266,8 @@ static PetscErrorCode SVDCyclicGetECrossMat(SVD svd,Mat A,Mat AT,Mat *C,Vec t)
   Mat              Id,Zm,Zn,ATA;
 #if defined(PETSC_HAVE_CUDA)
   PetscBool        cuda;
+  const PetscInt   *ranges;
+  PetscMPIInt      size;
 #endif
 
   PetscFunctionBegin;
@@ -303,6 +330,21 @@ static PetscErrorCode SVDCyclicGetECrossMat(SVD svd,Mat A,Mat AT,Mat *C,Vec t)
       PetscCall(MatShellSetOperation(*C,MATOP_MULT,(void(*)(void))MatMult_ECross));
     PetscCall(MatGetVecType(A,&vtype));
     PetscCall(MatSetVecType(*C,vtype));
+#if defined(PETSC_HAVE_CUDA)
+    if (cuda) {
+      /* check alignment of bottom block */
+      PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)ctx->x1),&size));
+      PetscCall(VecGetOwnershipRanges(ctx->x1,&ranges));
+      for (i=0;i<size;i++) {
+        ctx->misaligned = (((ranges[i+1]-ranges[i])*sizeof(PetscScalar))%16)? PETSC_TRUE: PETSC_FALSE;
+        if (ctx->misaligned) break;
+      }
+      if (ctx->misaligned) {  /* create work vectors for MatMult */
+        PetscCall(VecDuplicate(ctx->x2,&ctx->wx2));
+        PetscCall(VecDuplicate(ctx->y2,&ctx->wy2));
+      }
+    }
+#endif
   }
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -317,7 +359,7 @@ static PetscErrorCode EPSConv_Cyclic(EPS eps,PetscScalar eigr,PetscScalar eigi,P
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDSetUp_Cyclic(SVD svd)
+static PetscErrorCode SVDSetUp_Cyclic(SVD svd)
 {
   SVD_CYCLIC        *cyclic = (SVD_CYCLIC*)svd->data;
   PetscInt          M,N,m,n,p,k,i,isl,offset,nev,ncv,mpd,maxit;
@@ -474,7 +516,7 @@ PetscErrorCode SVDSetUp_Cyclic(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDCyclicCheckEigenvalue(SVD svd,PetscScalar er,PetscScalar ei,PetscReal *sigma,PetscBool *isreal)
+static PetscErrorCode SVDCyclicCheckEigenvalue(SVD svd,PetscScalar er,PetscScalar ei,PetscReal *sigma,PetscBool *isreal)
 {
   PetscFunctionBegin;
   if (svd->ishyperbolic && PetscDefined(USE_COMPLEX) && PetscAbsReal(PetscImaginaryPart(er))>10*PetscAbsReal(PetscRealPart(er))) {
@@ -490,7 +532,7 @@ PetscErrorCode SVDCyclicCheckEigenvalue(SVD svd,PetscScalar er,PetscScalar ei,Pe
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDSolve_Cyclic(SVD svd)
+static PetscErrorCode SVDSolve_Cyclic(SVD svd)
 {
   SVD_CYCLIC     *cyclic = (SVD_CYCLIC*)svd->data;
   PetscInt       i,j,nconv;
@@ -758,7 +800,7 @@ static PetscErrorCode SVDComputeVectors_Cyclic_Hyperbolic(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDComputeVectors_Cyclic(SVD svd)
+static PetscErrorCode SVDComputeVectors_Cyclic(SVD svd)
 {
   PetscFunctionBegin;
   switch (svd->problem_type) {
@@ -804,7 +846,7 @@ static PetscErrorCode EPSMonitor_Cyclic(EPS eps,PetscInt its,PetscInt nconv,Pets
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDSetFromOptions_Cyclic(SVD svd,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode SVDSetFromOptions_Cyclic(SVD svd,PetscOptionItems *PetscOptionsObject)
 {
   PetscBool      set,val;
   SVD_CYCLIC     *cyclic = (SVD_CYCLIC*)svd->data;
@@ -894,7 +936,7 @@ PetscErrorCode SVDCyclicGetExplicitMatrix(SVD svd,PetscBool *explicitmat)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  PetscValidBoolPointer(explicitmat,2);
+  PetscAssertPointer(explicitmat,2);
   PetscUseMethod(svd,"SVDCyclicGetExplicitMatrix_C",(SVD,PetscBool*),(svd,explicitmat));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -974,12 +1016,12 @@ PetscErrorCode SVDCyclicGetEPS(SVD svd,EPS *eps)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  PetscValidPointer(eps,2);
+  PetscAssertPointer(eps,2);
   PetscUseMethod(svd,"SVDCyclicGetEPS_C",(SVD,EPS*),(svd,eps));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDView_Cyclic(SVD svd,PetscViewer viewer)
+static PetscErrorCode SVDView_Cyclic(SVD svd,PetscViewer viewer)
 {
   SVD_CYCLIC     *cyclic = (SVD_CYCLIC*)svd->data;
   PetscBool      isascii;
@@ -996,7 +1038,7 @@ PetscErrorCode SVDView_Cyclic(SVD svd,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDReset_Cyclic(SVD svd)
+static PetscErrorCode SVDReset_Cyclic(SVD svd)
 {
   SVD_CYCLIC     *cyclic = (SVD_CYCLIC*)svd->data;
 
@@ -1007,7 +1049,7 @@ PetscErrorCode SVDReset_Cyclic(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDDestroy_Cyclic(SVD svd)
+static PetscErrorCode SVDDestroy_Cyclic(SVD svd)
 {
   SVD_CYCLIC     *cyclic = (SVD_CYCLIC*)svd->data;
 
