@@ -144,7 +144,7 @@ static void multMatvec_PRIMME(void *xa,PRIMME_INT *ldx,void *ya,PRIMME_INT *ldy,
   PetscFunctionReturnVoid();
 }
 
-PetscErrorCode SVDSetUp_PRIMME(SVD svd)
+static PetscErrorCode SVDSetUp_PRIMME(SVD svd)
 {
   PetscMPIInt        numProcs,procID;
   PetscInt           n,m,nloc,mloc;
@@ -225,11 +225,11 @@ PetscErrorCode SVDSetUp_PRIMME(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDSolve_PRIMME(SVD svd)
+static PetscErrorCode SVDSolve_PRIMME(SVD svd)
 {
   SVD_PRIMME     *ops = (SVD_PRIMME*)svd->data;
   PetscScalar    *svecs, *a;
-  PetscInt       i,ierrprimme;
+  PetscInt       i,ierrprimme,ld;
   PetscReal      *svals,*rnorms;
 
   PetscFunctionBegin;
@@ -252,12 +252,14 @@ PetscErrorCode SVDSolve_PRIMME(SVD svd)
   PetscCall(PetscFree2(svals,rnorms));
 
   /* Copy left and right singular vectors into svd */
+  PetscCall(BVGetLeadingDimension(svd->U,&ld));
   PetscCall(BVGetArray(svd->U,&a));
-  PetscCall(PetscArraycpy(a,svecs,ops->primme.mLocal*ops->primme.initSize));
+  for (i=0;i<ops->primme.initSize;i++) PetscCall(PetscArraycpy(a+i*ld,svecs+i*ops->primme.mLocal,ops->primme.mLocal));
   PetscCall(BVRestoreArray(svd->U,&a));
 
+  PetscCall(BVGetLeadingDimension(svd->V,&ld));
   PetscCall(BVGetArray(svd->V,&a));
-  PetscCall(PetscArraycpy(a,svecs+ops->primme.mLocal*ops->primme.initSize,ops->primme.nLocal*ops->primme.initSize));
+  for (i=0;i<ops->primme.initSize;i++) PetscCall(PetscArraycpy(a+i*ld,svecs+ops->primme.mLocal*ops->primme.initSize+i*ops->primme.nLocal,ops->primme.nLocal));
   PetscCall(BVRestoreArray(svd->V,&a));
 
   PetscCall(PetscFree(svecs));
@@ -283,7 +285,7 @@ PetscErrorCode SVDSolve_PRIMME(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDReset_PRIMME(SVD svd)
+static PetscErrorCode SVDReset_PRIMME(SVD svd)
 {
   SVD_PRIMME     *ops = (SVD_PRIMME*)svd->data;
 
@@ -294,7 +296,7 @@ PetscErrorCode SVDReset_PRIMME(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDDestroy_PRIMME(SVD svd)
+static PetscErrorCode SVDDestroy_PRIMME(SVD svd)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(svd->data));
@@ -305,7 +307,7 @@ PetscErrorCode SVDDestroy_PRIMME(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDView_PRIMME(SVD svd,PetscViewer viewer)
+static PetscErrorCode SVDView_PRIMME(SVD svd,PetscViewer viewer)
 {
   PetscBool      isascii;
   SVD_PRIMME     *ctx = (SVD_PRIMME*)svd->data;
@@ -324,7 +326,7 @@ PetscErrorCode SVDView_PRIMME(SVD svd,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode SVDSetFromOptions_PRIMME(SVD svd,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode SVDSetFromOptions_PRIMME(SVD svd,PetscOptionItems *PetscOptionsObject)
 {
   SVD_PRIMME      *ctx = (SVD_PRIMME*)svd->data;
   PetscInt        bs;
@@ -419,7 +421,7 @@ PetscErrorCode SVDPRIMMEGetBlockSize(SVD svd,PetscInt *bs)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  PetscValidIntPointer(bs,2);
+  PetscAssertPointer(bs,2);
   PetscUseMethod(svd,"SVDPRIMMEGetBlockSize_C",(SVD,PetscInt*),(svd,bs));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -489,7 +491,7 @@ PetscErrorCode SVDPRIMMEGetMethod(SVD svd,SVDPRIMMEMethod *method)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(svd,SVD_CLASSID,1);
-  PetscValidPointer(method,2);
+  PetscAssertPointer(method,2);
   PetscUseMethod(svd,"SVDPRIMMEGetMethod_C",(SVD,SVDPRIMMEMethod*),(svd,method));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
