@@ -12,13 +12,9 @@
 */
 
 #include <slepc/private/bvimpl.h>
+#include "bvmat.h"
 
-typedef struct {
-  Mat       A;
-  PetscBool mpi;
-} BV_MAT;
-
-PetscErrorCode BVMult_Mat(BV Y,PetscScalar alpha,PetscScalar beta,BV X,Mat Q)
+static PetscErrorCode BVMult_Mat(BV Y,PetscScalar alpha,PetscScalar beta,BV X,Mat Q)
 {
   BV_MAT            *y = (BV_MAT*)Y->data,*x = (BV_MAT*)X->data;
   PetscScalar       *py;
@@ -31,15 +27,15 @@ PetscErrorCode BVMult_Mat(BV Y,PetscScalar alpha,PetscScalar beta,BV X,Mat Q)
   if (Q) {
     PetscCall(MatDenseGetLDA(Q,&ldq));
     PetscCall(MatDenseGetArrayRead(Q,&q));
-    PetscCall(BVMult_BLAS_Private(Y,Y->n,Y->k-Y->l,X->k-X->l,ldq,alpha,px+(X->nc+X->l)*X->n,q+Y->l*ldq+X->l,beta,py+(Y->nc+Y->l)*Y->n));
+    PetscCall(BVMult_BLAS_Private(Y,Y->n,Y->k-Y->l,X->k-X->l,alpha,px+(X->nc+X->l)*X->ld,X->ld,q+Y->l*ldq+X->l,ldq,beta,py+(Y->nc+Y->l)*Y->ld,Y->ld));
     PetscCall(MatDenseRestoreArrayRead(Q,&q));
-  } else PetscCall(BVAXPY_BLAS_Private(Y,Y->n,Y->k-Y->l,alpha,px+(X->nc+X->l)*X->n,beta,py+(Y->nc+Y->l)*Y->n));
+  } else PetscCall(BVAXPY_BLAS_Private(Y,Y->n,Y->k-Y->l,alpha,px+(X->nc+X->l)*X->ld,X->ld,beta,py+(Y->nc+Y->l)*Y->ld,Y->ld));
   PetscCall(MatDenseRestoreArrayRead(x->A,&px));
   PetscCall(MatDenseRestoreArray(y->A,&py));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVMultVec_Mat(BV X,PetscScalar alpha,PetscScalar beta,Vec y,PetscScalar *q)
+static PetscErrorCode BVMultVec_Mat(BV X,PetscScalar alpha,PetscScalar beta,Vec y,PetscScalar *q)
 {
   BV_MAT            *x = (BV_MAT*)X->data;
   PetscScalar       *py,*qq=q;
@@ -49,14 +45,14 @@ PetscErrorCode BVMultVec_Mat(BV X,PetscScalar alpha,PetscScalar beta,Vec y,Petsc
   PetscCall(MatDenseGetArrayRead(x->A,&px));
   PetscCall(VecGetArray(y,&py));
   if (!q) PetscCall(VecGetArray(X->buffer,&qq));
-  PetscCall(BVMultVec_BLAS_Private(X,X->n,X->k-X->l,alpha,px+(X->nc+X->l)*X->n,qq,beta,py));
+  PetscCall(BVMultVec_BLAS_Private(X,X->n,X->k-X->l,alpha,px+(X->nc+X->l)*X->ld,X->ld,qq,beta,py));
   if (!q) PetscCall(VecRestoreArray(X->buffer,&qq));
   PetscCall(MatDenseRestoreArrayRead(x->A,&px));
   PetscCall(VecRestoreArray(y,&py));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVMultInPlace_Mat(BV V,Mat Q,PetscInt s,PetscInt e)
+static PetscErrorCode BVMultInPlace_Mat(BV V,Mat Q,PetscInt s,PetscInt e)
 {
   BV_MAT            *ctx = (BV_MAT*)V->data;
   PetscScalar       *pv;
@@ -64,16 +60,17 @@ PetscErrorCode BVMultInPlace_Mat(BV V,Mat Q,PetscInt s,PetscInt e)
   PetscInt          ldq;
 
   PetscFunctionBegin;
+  if (s>=e || !V->n) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(MatDenseGetLDA(Q,&ldq));
   PetscCall(MatDenseGetArray(ctx->A,&pv));
   PetscCall(MatDenseGetArrayRead(Q,&q));
-  PetscCall(BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,ldq,s-V->l,e-V->l,pv+(V->nc+V->l)*V->n,q+V->l*ldq+V->l,PETSC_FALSE));
+  PetscCall(BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,s-V->l,e-V->l,pv+(V->nc+V->l)*V->ld,V->ld,q+V->l*ldq+V->l,ldq,PETSC_FALSE));
   PetscCall(MatDenseRestoreArrayRead(Q,&q));
   PetscCall(MatDenseRestoreArray(ctx->A,&pv));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVMultInPlaceHermitianTranspose_Mat(BV V,Mat Q,PetscInt s,PetscInt e)
+static PetscErrorCode BVMultInPlaceHermitianTranspose_Mat(BV V,Mat Q,PetscInt s,PetscInt e)
 {
   BV_MAT            *ctx = (BV_MAT*)V->data;
   PetscScalar       *pv;
@@ -81,16 +78,17 @@ PetscErrorCode BVMultInPlaceHermitianTranspose_Mat(BV V,Mat Q,PetscInt s,PetscIn
   PetscInt          ldq;
 
   PetscFunctionBegin;
+  if (s>=e || !V->n) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(MatDenseGetLDA(Q,&ldq));
   PetscCall(MatDenseGetArray(ctx->A,&pv));
   PetscCall(MatDenseGetArrayRead(Q,&q));
-  PetscCall(BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,ldq,s-V->l,e-V->l,pv+(V->nc+V->l)*V->n,q+V->l*ldq+V->l,PETSC_TRUE));
+  PetscCall(BVMultInPlace_BLAS_Private(V,V->n,V->k-V->l,s-V->l,e-V->l,pv+(V->nc+V->l)*V->ld,V->ld,q+V->l*ldq+V->l,ldq,PETSC_TRUE));
   PetscCall(MatDenseRestoreArrayRead(Q,&q));
   PetscCall(MatDenseRestoreArray(ctx->A,&pv));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVDot_Mat(BV X,BV Y,Mat M)
+static PetscErrorCode BVDot_Mat(BV X,BV Y,Mat M)
 {
   BV_MAT            *x = (BV_MAT*)X->data,*y = (BV_MAT*)Y->data;
   PetscScalar       *m;
@@ -102,14 +100,14 @@ PetscErrorCode BVDot_Mat(BV X,BV Y,Mat M)
   PetscCall(MatDenseGetArrayRead(x->A,&px));
   PetscCall(MatDenseGetArrayRead(y->A,&py));
   PetscCall(MatDenseGetArray(M,&m));
-  PetscCall(BVDot_BLAS_Private(X,Y->k-Y->l,X->k-X->l,X->n,ldm,py+(Y->nc+Y->l)*Y->n,px+(X->nc+X->l)*X->n,m+X->l*ldm+Y->l,x->mpi));
+  PetscCall(BVDot_BLAS_Private(X,Y->k-Y->l,X->k-X->l,X->n,py+(Y->nc+Y->l)*Y->ld,Y->ld,px+(X->nc+X->l)*X->ld,X->ld,m+X->l*ldm+Y->l,ldm,x->mpi));
   PetscCall(MatDenseRestoreArray(M,&m));
   PetscCall(MatDenseRestoreArrayRead(x->A,&px));
   PetscCall(MatDenseRestoreArrayRead(y->A,&py));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVDotVec_Mat(BV X,Vec y,PetscScalar *q)
+static PetscErrorCode BVDotVec_Mat(BV X,Vec y,PetscScalar *q)
 {
   BV_MAT            *x = (BV_MAT*)X->data;
   PetscScalar       *qq=q;
@@ -124,14 +122,14 @@ PetscErrorCode BVDotVec_Mat(BV X,Vec y,PetscScalar *q)
   PetscCall(MatDenseGetArrayRead(x->A,&px));
   PetscCall(VecGetArrayRead(z,&py));
   if (!q) PetscCall(VecGetArray(X->buffer,&qq));
-  PetscCall(BVDotVec_BLAS_Private(X,X->n,X->k-X->l,px+(X->nc+X->l)*X->n,py,qq,x->mpi));
+  PetscCall(BVDotVec_BLAS_Private(X,X->n,X->k-X->l,px+(X->nc+X->l)*X->ld,X->ld,py,qq,x->mpi));
   if (!q) PetscCall(VecRestoreArray(X->buffer,&qq));
   PetscCall(VecRestoreArrayRead(z,&py));
   PetscCall(MatDenseRestoreArrayRead(x->A,&px));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVDotVec_Local_Mat(BV X,Vec y,PetscScalar *m)
+static PetscErrorCode BVDotVec_Local_Mat(BV X,Vec y,PetscScalar *m)
 {
   BV_MAT            *x = (BV_MAT*)X->data;
   const PetscScalar *px,*py;
@@ -144,52 +142,53 @@ PetscErrorCode BVDotVec_Local_Mat(BV X,Vec y,PetscScalar *m)
   }
   PetscCall(MatDenseGetArrayRead(x->A,&px));
   PetscCall(VecGetArrayRead(z,&py));
-  PetscCall(BVDotVec_BLAS_Private(X,X->n,X->k-X->l,px+(X->nc+X->l)*X->n,py,m,PETSC_FALSE));
+  PetscCall(BVDotVec_BLAS_Private(X,X->n,X->k-X->l,px+(X->nc+X->l)*X->ld,X->ld,py,m,PETSC_FALSE));
   PetscCall(VecRestoreArrayRead(z,&py));
   PetscCall(MatDenseRestoreArrayRead(x->A,&px));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVScale_Mat(BV bv,PetscInt j,PetscScalar alpha)
+static PetscErrorCode BVScale_Mat(BV bv,PetscInt j,PetscScalar alpha)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
   PetscScalar    *array;
 
   PetscFunctionBegin;
+  if (!bv->n) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(MatDenseGetArray(ctx->A,&array));
-  if (PetscUnlikely(j<0)) PetscCall(BVScale_BLAS_Private(bv,(bv->k-bv->l)*bv->n,array+(bv->nc+bv->l)*bv->n,alpha));
-  else PetscCall(BVScale_BLAS_Private(bv,bv->n,array+(bv->nc+j)*bv->n,alpha));
+  if (PetscUnlikely(j<0)) PetscCall(BVScale_BLAS_Private(bv,(bv->k-bv->l)*bv->ld,array+(bv->nc+bv->l)*bv->ld,alpha));
+  else PetscCall(BVScale_BLAS_Private(bv,bv->n,array+(bv->nc+j)*bv->ld,alpha));
   PetscCall(MatDenseRestoreArray(ctx->A,&array));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVNorm_Mat(BV bv,PetscInt j,NormType type,PetscReal *val)
+static PetscErrorCode BVNorm_Mat(BV bv,PetscInt j,NormType type,PetscReal *val)
 {
   BV_MAT            *ctx = (BV_MAT*)bv->data;
   const PetscScalar *array;
 
   PetscFunctionBegin;
   PetscCall(MatDenseGetArrayRead(ctx->A,&array));
-  if (PetscUnlikely(j<0)) PetscCall(BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,array+(bv->nc+bv->l)*bv->n,type,val,ctx->mpi));
-  else PetscCall(BVNorm_LAPACK_Private(bv,bv->n,1,array+(bv->nc+j)*bv->n,type,val,ctx->mpi));
+  if (PetscUnlikely(j<0)) PetscCall(BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,array+(bv->nc+bv->l)*bv->ld,bv->ld,type,val,ctx->mpi));
+  else PetscCall(BVNorm_LAPACK_Private(bv,bv->n,1,array+(bv->nc+j)*bv->ld,bv->ld,type,val,ctx->mpi));
   PetscCall(MatDenseRestoreArrayRead(ctx->A,&array));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVNorm_Local_Mat(BV bv,PetscInt j,NormType type,PetscReal *val)
+static PetscErrorCode BVNorm_Local_Mat(BV bv,PetscInt j,NormType type,PetscReal *val)
 {
   BV_MAT            *ctx = (BV_MAT*)bv->data;
   const PetscScalar *array;
 
   PetscFunctionBegin;
   PetscCall(MatDenseGetArrayRead(ctx->A,&array));
-  if (PetscUnlikely(j<0)) PetscCall(BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,array+(bv->nc+bv->l)*bv->n,type,val,PETSC_FALSE));
-  else PetscCall(BVNorm_LAPACK_Private(bv,bv->n,1,array+(bv->nc+j)*bv->n,type,val,PETSC_FALSE));
+  if (PetscUnlikely(j<0)) PetscCall(BVNorm_LAPACK_Private(bv,bv->n,bv->k-bv->l,array+(bv->nc+bv->l)*bv->ld,bv->ld,type,val,PETSC_FALSE));
+  else PetscCall(BVNorm_LAPACK_Private(bv,bv->n,1,array+(bv->nc+j)*bv->ld,bv->ld,type,val,PETSC_FALSE));
   PetscCall(MatDenseRestoreArrayRead(ctx->A,&array));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVNormalize_Mat(BV bv,PetscScalar *eigi)
+static PetscErrorCode BVNormalize_Mat(BV bv,PetscScalar *eigi)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
   PetscScalar    *array,*wi=NULL;
@@ -197,12 +196,12 @@ PetscErrorCode BVNormalize_Mat(BV bv,PetscScalar *eigi)
   PetscFunctionBegin;
   PetscCall(MatDenseGetArray(ctx->A,&array));
   if (eigi) wi = eigi+bv->l;
-  PetscCall(BVNormalize_LAPACK_Private(bv,bv->n,bv->k-bv->l,array+(bv->nc+bv->l)*bv->n,wi,ctx->mpi));
+  PetscCall(BVNormalize_LAPACK_Private(bv,bv->n,bv->k-bv->l,array+(bv->nc+bv->l)*bv->ld,bv->ld,wi,ctx->mpi));
   PetscCall(MatDenseRestoreArray(ctx->A,&array));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVMatMult_Mat(BV V,Mat A,BV W)
+static PetscErrorCode BVMatMult_Mat(BV V,Mat A,BV W)
 {
   PetscInt       j;
   Mat            Vmat,Wmat;
@@ -232,62 +231,61 @@ PetscErrorCode BVMatMult_Mat(BV V,Mat A,BV W)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVCopy_Mat(BV V,BV W)
+static PetscErrorCode BVCopy_Mat(BV V,BV W)
 {
   BV_MAT            *v = (BV_MAT*)V->data,*w = (BV_MAT*)W->data;
-  PetscScalar       *pw,*pwc;
-  const PetscScalar *pv,*pvc;
+  const PetscScalar *pv;
+  PetscScalar       *pw;
+  PetscInt          j;
 
   PetscFunctionBegin;
   PetscCall(MatDenseGetArrayRead(v->A,&pv));
   PetscCall(MatDenseGetArray(w->A,&pw));
-  pvc = pv+(V->nc+V->l)*V->n;
-  pwc = pw+(W->nc+W->l)*W->n;
-  PetscCall(PetscArraycpy(pwc,pvc,(V->k-V->l)*V->n));
+  for (j=0;j<V->k-V->l;j++) PetscCall(PetscArraycpy(pw+(W->nc+W->l+j)*W->ld,pv+(V->nc+V->l+j)*V->ld,V->n));
   PetscCall(MatDenseRestoreArrayRead(v->A,&pv));
   PetscCall(MatDenseRestoreArray(w->A,&pw));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVCopyColumn_Mat(BV V,PetscInt j,PetscInt i)
+static PetscErrorCode BVCopyColumn_Mat(BV V,PetscInt j,PetscInt i)
 {
   BV_MAT         *v = (BV_MAT*)V->data;
   PetscScalar    *pv;
 
   PetscFunctionBegin;
   PetscCall(MatDenseGetArray(v->A,&pv));
-  PetscCall(PetscArraycpy(pv+(V->nc+i)*V->n,pv+(V->nc+j)*V->n,V->n));
+  PetscCall(PetscArraycpy(pv+(V->nc+i)*V->ld,pv+(V->nc+j)*V->ld,V->n));
   PetscCall(MatDenseRestoreArray(v->A,&pv));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVResize_Mat(BV bv,PetscInt m,PetscBool copy)
+static PetscErrorCode BVResize_Mat(BV bv,PetscInt m,PetscBool copy)
 {
   BV_MAT            *ctx = (BV_MAT*)bv->data;
-  PetscScalar       *pnew;
-  const PetscScalar *pA;
-  Mat               A;
+  Mat               A,Msrc,Mdst;
+  VecType           vtype;
   char              str[50];
 
   PetscFunctionBegin;
-  PetscCall(MatCreateDense(PetscObjectComm((PetscObject)bv->t),bv->n,PETSC_DECIDE,PETSC_DECIDE,m,NULL,&A));
+  PetscCall(VecGetType(bv->t,&vtype));
+  PetscCall(MatCreateDenseFromVecType(PetscObjectComm((PetscObject)bv->t),vtype,bv->n,PETSC_DECIDE,bv->N,m,bv->ld,NULL,&A));
   if (((PetscObject)bv)->name) {
     PetscCall(PetscSNPrintf(str,sizeof(str),"%s_0",((PetscObject)bv)->name));
     PetscCall(PetscObjectSetName((PetscObject)A,str));
   }
   if (copy) {
-    PetscCall(MatDenseGetArrayRead(ctx->A,&pA));
-    PetscCall(MatDenseGetArrayWrite(A,&pnew));
-    PetscCall(PetscArraycpy(pnew,pA,PetscMin(m,bv->m)*bv->n));
-    PetscCall(MatDenseRestoreArrayRead(ctx->A,&pA));
-    PetscCall(MatDenseRestoreArrayWrite(A,&pnew));
+    PetscCall(MatDenseGetSubMatrix(ctx->A,PETSC_DECIDE,PETSC_DECIDE,PETSC_DECIDE,PetscMin(m,bv->m),&Msrc));
+    PetscCall(MatDenseGetSubMatrix(A,PETSC_DECIDE,PETSC_DECIDE,PETSC_DECIDE,PetscMin(m,bv->m),&Mdst));
+    PetscCall(MatCopy(Msrc,Mdst,SAME_NONZERO_PATTERN));
+    PetscCall(MatDenseRestoreSubMatrix(ctx->A,&Msrc));
+    PetscCall(MatDenseRestoreSubMatrix(A,&Mdst));
   }
   PetscCall(MatDestroy(&ctx->A));
   ctx->A = A;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVGetColumn_Mat(BV bv,PetscInt j,Vec *v)
+static PetscErrorCode BVGetColumn_Mat(BV bv,PetscInt j,Vec *v)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
   PetscScalar    *pA;
@@ -296,11 +294,11 @@ PetscErrorCode BVGetColumn_Mat(BV bv,PetscInt j,Vec *v)
   PetscFunctionBegin;
   l = BVAvailableVec;
   PetscCall(MatDenseGetArray(ctx->A,&pA));
-  PetscCall(VecPlaceArray(bv->cv[l],pA+(bv->nc+j)*bv->n));
+  PetscCall(VecPlaceArray(bv->cv[l],pA+(bv->nc+j)*bv->ld));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVRestoreColumn_Mat(BV bv,PetscInt j,Vec *v)
+static PetscErrorCode BVRestoreColumn_Mat(BV bv,PetscInt j,Vec *v)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
   PetscScalar    *pA;
@@ -313,7 +311,7 @@ PetscErrorCode BVRestoreColumn_Mat(BV bv,PetscInt j,Vec *v)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVGetArray_Mat(BV bv,PetscScalar **a)
+static PetscErrorCode BVGetArray_Mat(BV bv,PetscScalar **a)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
 
@@ -322,7 +320,7 @@ PetscErrorCode BVGetArray_Mat(BV bv,PetscScalar **a)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVRestoreArray_Mat(BV bv,PetscScalar **a)
+static PetscErrorCode BVRestoreArray_Mat(BV bv,PetscScalar **a)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
 
@@ -331,7 +329,7 @@ PetscErrorCode BVRestoreArray_Mat(BV bv,PetscScalar **a)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVGetArrayRead_Mat(BV bv,const PetscScalar **a)
+static PetscErrorCode BVGetArrayRead_Mat(BV bv,const PetscScalar **a)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
 
@@ -340,7 +338,7 @@ PetscErrorCode BVGetArrayRead_Mat(BV bv,const PetscScalar **a)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVRestoreArrayRead_Mat(BV bv,const PetscScalar **a)
+static PetscErrorCode BVRestoreArrayRead_Mat(BV bv,const PetscScalar **a)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
 
@@ -349,7 +347,7 @@ PetscErrorCode BVRestoreArrayRead_Mat(BV bv,const PetscScalar **a)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVView_Mat(BV bv,PetscViewer viewer)
+static PetscErrorCode BVView_Mat(BV bv,PetscViewer viewer)
 {
   BV_MAT            *ctx = (BV_MAT*)bv->data;
   PetscViewerFormat format;
@@ -372,7 +370,7 @@ PetscErrorCode BVView_Mat(BV bv,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVDestroy_Mat(BV bv)
+static PetscErrorCode BVDestroy_Mat(BV bv)
 {
   BV_MAT         *ctx = (BV_MAT*)bv->data;
 
@@ -390,70 +388,102 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Mat(BV bv)
   PetscInt       nloc,bs,lsplit;
   PetscBool      seq;
   char           str[50];
-  PetscScalar    *array,*ptr;
+  PetscScalar    *array,*ptr=NULL;
   BV             parent;
+  Mat            Apar;
+  VecType        vtype;
 
   PetscFunctionBegin;
   PetscCall(PetscNew(&ctx));
   bv->data = (void*)ctx;
 
-  PetscCall(PetscObjectTypeCompare((PetscObject)bv->t,VECMPI,&ctx->mpi));
-  if (!ctx->mpi) {
-    PetscCall(PetscObjectTypeCompare((PetscObject)bv->t,VECSEQ,&seq));
-    PetscCheck(seq,PetscObjectComm((PetscObject)bv),PETSC_ERR_SUP,"Cannot create a BVMAT from a non-standard template vector");
-  }
+  PetscCall(PetscObjectTypeCompareAny((PetscObject)bv->t,&bv->cuda,VECSEQCUDA,VECMPICUDA,""));
+  PetscCall(PetscObjectTypeCompareAny((PetscObject)bv->t,&ctx->mpi,VECMPI,VECMPICUDA,""));
+
+  PetscCall(PetscObjectTypeCompare((PetscObject)bv->t,VECSEQ,&seq));
+  PetscCheck(seq || ctx->mpi || bv->cuda,PetscObjectComm((PetscObject)bv),PETSC_ERR_SUP,"BVMAT does not support the type of the provided template vector");
 
   PetscCall(VecGetLocalSize(bv->t,&nloc));
   PetscCall(VecGetBlockSize(bv->t,&bs));
+  PetscCall(BV_SetDefaultLD(bv,nloc));
 
   if (PetscUnlikely(bv->issplit)) {
     /* split BV: share the memory of the parent BV */
     parent = bv->splitparent;
     lsplit = parent->lsplit;
-    PetscCall(MatDenseGetArray(((BV_MAT*)parent->data)->A,&array));
-    ptr = (bv->issplit==1)? array: array+lsplit*nloc;
-    PetscCall(MatDenseRestoreArray(((BV_MAT*)parent->data)->A,&array));
-  } else {
-    /* regular BV: allocate memory for the BV entries */
-    ptr = NULL;
+    Apar = ((BV_MAT*)parent->data)->A;
+    if (bv->cuda) {
+#if defined(PETSC_HAVE_CUDA)
+      PetscCall(MatDenseCUDAGetArray(Apar,&array));
+      ptr = (bv->issplit==1)? array: array+lsplit*bv->ld;
+      PetscCall(MatDenseCUDARestoreArray(Apar,&array));
+#endif
+    } else {
+      PetscCall(MatDenseGetArray(Apar,&array));
+      ptr = (bv->issplit==1)? array: array+lsplit*bv->ld;
+      PetscCall(MatDenseRestoreArray(Apar,&array));
+    }
   }
-  PetscCall(MatCreateDense(PetscObjectComm((PetscObject)bv->t),nloc,PETSC_DECIDE,PETSC_DECIDE,bv->m,ptr,&ctx->A));
+
+  PetscCall(VecGetType(bv->t,&vtype));
+  PetscCall(MatCreateDenseFromVecType(PetscObjectComm((PetscObject)bv->t),vtype,nloc,PETSC_DECIDE,bv->N,bv->m,bv->ld,ptr,&ctx->A));
   if (((PetscObject)bv)->name) {
     PetscCall(PetscSNPrintf(str,sizeof(str),"%s_0",((PetscObject)bv)->name));
     PetscCall(PetscObjectSetName((PetscObject)ctx->A,str));
   }
 
   if (PetscUnlikely(bv->Acreate)) {
-    PetscCall(MatCopy(bv->Acreate,ctx->A,SAME_NONZERO_PATTERN));
+    PetscCall(MatConvert(bv->Acreate,MATDENSE,MAT_REUSE_MATRIX,&ctx->A));
     PetscCall(MatDestroy(&bv->Acreate));
   }
 
   PetscCall(VecDuplicateEmpty(bv->t,&bv->cv[0]));
   PetscCall(VecDuplicateEmpty(bv->t,&bv->cv[1]));
 
-  bv->ops->mult             = BVMult_Mat;
-  bv->ops->multvec          = BVMultVec_Mat;
-  bv->ops->multinplace      = BVMultInPlace_Mat;
-  bv->ops->multinplacetrans = BVMultInPlaceHermitianTranspose_Mat;
-  bv->ops->dot              = BVDot_Mat;
-  bv->ops->dotvec           = BVDotVec_Mat;
-  bv->ops->dotvec_local     = BVDotVec_Local_Mat;
-  bv->ops->scale            = BVScale_Mat;
+  if (bv->cuda) {
+#if defined(PETSC_HAVE_CUDA)
+    bv->ops->mult             = BVMult_Mat_CUDA;
+    bv->ops->multvec          = BVMultVec_Mat_CUDA;
+    bv->ops->multinplace      = BVMultInPlace_Mat_CUDA;
+    bv->ops->multinplacetrans = BVMultInPlaceHermitianTranspose_Mat_CUDA;
+    bv->ops->dot              = BVDot_Mat_CUDA;
+    bv->ops->dotvec           = BVDotVec_Mat_CUDA;
+    bv->ops->dotvec_local     = BVDotVec_Local_Mat_CUDA;
+    bv->ops->scale            = BVScale_Mat_CUDA;
+    bv->ops->matmult          = BVMatMult_Mat_CUDA;
+    bv->ops->copy             = BVCopy_Mat_CUDA;
+    bv->ops->copycolumn       = BVCopyColumn_Mat_CUDA;
+    bv->ops->getcolumn        = BVGetColumn_Mat_CUDA;
+    bv->ops->restorecolumn    = BVRestoreColumn_Mat_CUDA;
+    bv->ops->restoresplit     = BVRestoreSplit_Mat_CUDA;
+    bv->ops->getmat           = BVGetMat_Mat_CUDA;
+    bv->ops->restoremat       = BVRestoreMat_Mat_CUDA;
+#endif
+  } else {
+    bv->ops->mult             = BVMult_Mat;
+    bv->ops->multvec          = BVMultVec_Mat;
+    bv->ops->multinplace      = BVMultInPlace_Mat;
+    bv->ops->multinplacetrans = BVMultInPlaceHermitianTranspose_Mat;
+    bv->ops->dot              = BVDot_Mat;
+    bv->ops->dotvec           = BVDotVec_Mat;
+    bv->ops->dotvec_local     = BVDotVec_Local_Mat;
+    bv->ops->scale            = BVScale_Mat;
+    bv->ops->matmult          = BVMatMult_Mat;
+    bv->ops->copy             = BVCopy_Mat;
+    bv->ops->copycolumn       = BVCopyColumn_Mat;
+    bv->ops->getcolumn        = BVGetColumn_Mat;
+    bv->ops->restorecolumn    = BVRestoreColumn_Mat;
+    bv->ops->getmat           = BVGetMat_Default;
+    bv->ops->restoremat       = BVRestoreMat_Default;
+  }
   bv->ops->norm             = BVNorm_Mat;
   bv->ops->norm_local       = BVNorm_Local_Mat;
   bv->ops->normalize        = BVNormalize_Mat;
-  bv->ops->matmult          = BVMatMult_Mat;
-  bv->ops->copy             = BVCopy_Mat;
-  bv->ops->copycolumn       = BVCopyColumn_Mat;
   bv->ops->resize           = BVResize_Mat;
-  bv->ops->getcolumn        = BVGetColumn_Mat;
-  bv->ops->restorecolumn    = BVRestoreColumn_Mat;
   bv->ops->getarray         = BVGetArray_Mat;
   bv->ops->restorearray     = BVRestoreArray_Mat;
   bv->ops->getarrayread     = BVGetArrayRead_Mat;
   bv->ops->restorearrayread = BVRestoreArrayRead_Mat;
-  bv->ops->getmat           = BVGetMat_Default;
-  bv->ops->restoremat       = BVRestoreMat_Default;
   bv->ops->destroy          = BVDestroy_Mat;
   if (!ctx->mpi) bv->ops->view = BVView_Mat;
   PetscFunctionReturn(PETSC_SUCCESS);
