@@ -39,7 +39,7 @@ PetscErrorCode BVSetType(BV bv,BVType type)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidCharPointer(type,2);
+  PetscAssertPointer(type,2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)bv,type,&match));
   if (match) PetscFunctionReturn(PETSC_SUCCESS);
@@ -82,7 +82,7 @@ PetscErrorCode BVGetType(BV bv,BVType *type)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidPointer(type,2);
+  PetscAssertPointer(type,2);
   *type = ((PetscObject)bv)->type_name;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -304,7 +304,7 @@ PetscErrorCode BVGetNumConstraints(BV bv,PetscInt *nc)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidIntPointer(nc,2);
+  PetscAssertPointer(nc,2);
   *nc = bv->nc;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -761,7 +761,7 @@ PetscErrorCode BVGetBufferVec(BV bv,Vec *buffer)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidPointer(buffer,2);
+  PetscAssertPointer(buffer,2);
   BVCheckSizes(bv,1);
   if (!bv->buffer) {
     ld = bv->m+bv->nc;
@@ -818,7 +818,7 @@ PetscErrorCode BVGetRandomContext(BV bv,PetscRandom* rand)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidPointer(rand,2);
+  PetscAssertPointer(rand,2);
   if (!bv->rand) {
     PetscCall(PetscRandomCreate(PetscObjectComm((PetscObject)bv),&bv->rand));
     if (bv->cuda) PetscCall(PetscRandomSetType(bv->rand,PETSCCURAND));
@@ -857,9 +857,9 @@ PetscErrorCode BVSetFromOptions(BV bv)
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscCall(BVRegisterAll());
   PetscObjectOptionsBegin((PetscObject)bv);
-    PetscCall(PetscOptionsFList("-bv_type","Basis Vectors type","BVSetType",BVList,(char*)(((PetscObject)bv)->type_name?((PetscObject)bv)->type_name:BVSVEC),type,sizeof(type),&flg1));
+    PetscCall(PetscOptionsFList("-bv_type","Basis Vectors type","BVSetType",BVList,(char*)(((PetscObject)bv)->type_name?((PetscObject)bv)->type_name:BVMAT),type,sizeof(type),&flg1));
     if (flg1) PetscCall(BVSetType(bv,type));
-    else if (!((PetscObject)bv)->type_name) PetscCall(BVSetType(bv,BVSVEC));
+    else if (!((PetscObject)bv)->type_name) PetscCall(BVSetType(bv,BVMAT));
 
     otype = bv->orthog_type;
     PetscCall(PetscOptionsEnum("-bv_orthog_type","Orthogonalization method","BVSetOrthogonalization",BVOrthogTypes,(PetscEnum)otype,(PetscEnum*)&otype,&flg1));
@@ -1061,7 +1061,7 @@ PetscErrorCode BVGetMatMultMethod(BV bv,BVMatMultType *method)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidPointer(method,2);
+  PetscAssertPointer(method,2);
   *method = bv->vmm;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1146,7 +1146,7 @@ PetscErrorCode BVRestoreColumn(BV bv,PetscInt j,Vec *v)
   PetscValidType(bv,1);
   BVCheckSizes(bv,1);
   PetscValidLogicalCollectiveInt(bv,j,2);
-  PetscValidPointer(v,3);
+  PetscAssertPointer(v,3);
   PetscValidHeaderSpecific(*v,VEC_CLASSID,3);
   PetscCheck(j>=0 || -j<=bv->nc,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"You requested constraint %" PetscInt_FMT " but only %" PetscInt_FMT " are available",-j,bv->nc);
   PetscCheck(j<bv->m,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"You requested column %" PetscInt_FMT " but only %" PetscInt_FMT " are available",j,bv->m);
@@ -1184,9 +1184,15 @@ PetscErrorCode BVRestoreColumn(BV bv,PetscInt j,Vec *v)
    The pointer will normally point to the first entry of the first column,
    but if the BV has constraints then these go before the regular columns.
 
+   Note that for manipulating the pointer to the BV array, one must take into
+   account the leading dimension, which might be different from the local
+   number of rows, see BVGetLeadingDimension().
+
+   Use BVGetArrayRead() for read-only access.
+
    Level: advanced
 
-.seealso: BVRestoreArray(), BVInsertConstraints()
+.seealso: BVRestoreArray(), BVInsertConstraints(), BVGetLeadingDimension(), BVGetArrayRead()
 @*/
 PetscErrorCode BVGetArray(BV bv,PetscScalar **a)
 {
@@ -1250,7 +1256,7 @@ PetscErrorCode BVRestoreArray(BV bv,PetscScalar **a)
 
    Level: advanced
 
-.seealso: BVRestoreArray(), BVInsertConstraints()
+.seealso: BVRestoreArray(), BVInsertConstraints(), BVGetLeadingDimension(), BVGetArray()
 @*/
 PetscErrorCode BVGetArrayRead(BV bv,const PetscScalar **a)
 {
@@ -1312,7 +1318,7 @@ PetscErrorCode BVCreateVec(BV bv,Vec *v)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   BVCheckSizes(bv,1);
-  PetscValidPointer(v,2);
+  PetscAssertPointer(v,2);
   PetscCall(VecDuplicate(bv->t,v));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1340,20 +1346,26 @@ PetscErrorCode BVCreateVec(BV bv,Vec *v)
 @*/
 PetscErrorCode BVCreateMat(BV bv,Mat *A)
 {
-  PetscScalar       *aa;
-  const PetscScalar *vv;
+  PetscInt ksave,lsave;
+  Mat      B;
+  VecType  vtype;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   BVCheckSizes(bv,1);
-  PetscValidPointer(A,2);
+  PetscAssertPointer(A,2);
 
-  PetscCall(MatCreateDense(PetscObjectComm((PetscObject)bv->t),bv->n,PETSC_DECIDE,bv->N,bv->m,NULL,A));
-  PetscCall(MatDenseGetArrayWrite(*A,&aa));
-  PetscCall(BVGetArrayRead(bv,&vv));
-  PetscCall(PetscArraycpy(aa,vv,bv->m*bv->n));
-  PetscCall(BVRestoreArrayRead(bv,&vv));
-  PetscCall(MatDenseRestoreArrayWrite(*A,&aa));
+  PetscCall(VecGetType(bv->t,&vtype));
+  PetscCall(MatCreateDenseFromVecType(PetscObjectComm((PetscObject)bv->t),vtype,bv->n,PETSC_DECIDE,bv->N,bv->m,bv->ld,NULL,A));
+  lsave = bv->l;
+  ksave = bv->k;
+  bv->l = 0;
+  bv->k = bv->m;
+  PetscCall(BVGetMat(bv,&B));
+  PetscCall(MatCopy(B,*A,SAME_NONZERO_PATTERN));
+  PetscCall(BVRestoreMat(bv,&B));
+  bv->l = lsave;
+  bv->k = ksave;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
@@ -1362,6 +1374,7 @@ PetscErrorCode BVGetMat_Default(BV bv,Mat *A)
   PetscScalar *vv,*aa;
   PetscBool   create=PETSC_FALSE;
   PetscInt    m,cols;
+  VecType     vtype;
 
   PetscFunctionBegin;
   m = bv->k-bv->l;
@@ -1377,10 +1390,11 @@ PetscErrorCode BVGetMat_Default(BV bv,Mat *A)
   }
   PetscCall(BVGetArray(bv,&vv));
   if (create) {
-    PetscCall(MatCreateDense(PetscObjectComm((PetscObject)bv),bv->n,PETSC_DECIDE,bv->N,m,vv,&bv->Aget)); /* pass a pointer to avoid allocation of storage */
+    PetscCall(VecGetType(bv->t,&vtype));
+    PetscCall(MatCreateDenseFromVecType(PetscObjectComm((PetscObject)bv),vtype,bv->n,PETSC_DECIDE,bv->N,m,bv->ld,vv,&bv->Aget)); /* pass a pointer to avoid allocation of storage */
     PetscCall(MatDenseReplaceArray(bv->Aget,NULL));  /* replace with a null pointer, the value after BVRestoreMat */
   }
-  PetscCall(MatDensePlaceArray(bv->Aget,vv+(bv->nc+bv->l)*bv->n));  /* set the actual pointer */
+  PetscCall(MatDensePlaceArray(bv->Aget,vv+(bv->nc+bv->l)*bv->ld));  /* set the actual pointer */
   *A = bv->Aget;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1414,7 +1428,7 @@ PetscErrorCode BVGetMat(BV bv,Mat *A)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   BVCheckSizes(bv,1);
-  PetscValidPointer(A,2);
+  PetscAssertPointer(A,2);
   PetscUseTypeMethod(bv,getmat,A);
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1425,7 +1439,7 @@ PetscErrorCode BVRestoreMat_Default(BV bv,Mat *A)
 
   PetscFunctionBegin;
   PetscCall(MatDenseGetArray(bv->Aget,&aa));
-  vv = aa-(bv->nc+bv->l)*bv->n;
+  vv = aa-(bv->nc+bv->l)*bv->ld;
   PetscCall(MatDenseResetArray(bv->Aget));
   PetscCall(BVRestoreArray(bv,&vv));
   *A = NULL;
@@ -1455,7 +1469,7 @@ PetscErrorCode BVRestoreMat(BV bv,Mat *A)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   BVCheckSizes(bv,1);
-  PetscValidPointer(A,2);
+  PetscAssertPointer(A,2);
   PetscCheck(bv->Aget,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONGSTATE,"BVRestoreMat must match a previous call to BVGetMat");
   PetscCheck(bv->Aget==*A,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_WRONGSTATE,"Mat argument is not the same as the one obtained with BVGetMat");
   PetscUseTypeMethod(bv,restoremat,A);
@@ -1468,6 +1482,7 @@ PetscErrorCode BVRestoreMat(BV bv,Mat *A)
 static inline PetscErrorCode BVDuplicate_Private(BV V,BV W)
 {
   PetscFunctionBegin;
+  W->ld           = V->ld;
   PetscCall(BVSetType(W,((PetscObject)V)->type_name));
   W->orthog_type  = V->orthog_type;
   W->orthog_ref   = V->orthog_ref;
@@ -1517,7 +1532,7 @@ PetscErrorCode BVDuplicate(BV V,BV *W)
   PetscValidHeaderSpecific(V,BV_CLASSID,1);
   PetscValidType(V,1);
   BVCheckSizes(V,1);
-  PetscValidPointer(W,2);
+  PetscAssertPointer(W,2);
   PetscCall(BVCreate(PetscObjectComm((PetscObject)V),W));
   PetscCall(BVSetSizesFromVec(*W,V->t,V->m));
   PetscCall(BVDuplicate_Private(V,*W));
@@ -1552,7 +1567,7 @@ PetscErrorCode BVDuplicateResize(BV V,PetscInt m,BV *W)
   PetscValidType(V,1);
   BVCheckSizes(V,1);
   PetscValidLogicalCollectiveInt(V,m,2);
-  PetscValidPointer(W,3);
+  PetscAssertPointer(W,3);
   PetscCall(BVCreate(PetscObjectComm((PetscObject)V),W));
   PetscCall(BVSetSizesFromVec(*W,V->t,m));
   PetscCall(BVDuplicate_Private(V,*W));
@@ -1582,7 +1597,7 @@ PetscErrorCode BVGetCachedBV(BV bv,BV *cached)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidPointer(cached,2);
+  PetscAssertPointer(cached,2);
   BVCheckSizes(bv,1);
   if (!bv->cached) {
     PetscCall(BVCreate(PetscObjectComm((PetscObject)bv),&bv->cached));
@@ -1892,7 +1907,7 @@ PetscErrorCode BVSetDefiniteTolerance(BV bv,PetscReal deftol)
    Input Parameter:
 .  bv - the basis vectors
 
-   Output Parameters:
+   Output Parameter:
 .  deftol - the tolerance
 
    Level: advanced
@@ -1903,7 +1918,78 @@ PetscErrorCode BVGetDefiniteTolerance(BV bv,PetscReal *deftol)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
-  PetscValidRealPointer(deftol,2);
+  PetscAssertPointer(deftol,2);
   *deftol = bv->deftol;
   PetscFunctionReturn(PETSC_SUCCESS);
 }
+
+/*@
+   BVSetLeadingDimension - Set the leading dimension to be used for storing the BV data.
+
+   Not Collective
+
+   Input Parameters:
++  bv - basis vectors
+-  ld - the leading dimension
+
+   Notes:
+   This parameter is relevant for BVMAT, though it might be employed in other types
+   as well.
+
+   When the internal data of the BV is stored as a dense matrix, the leading dimension
+   has the same meaning as in MatDenseSetLDA(), i.e., the distance in number of
+   elements from one entry of the matrix to the one in the next column at the same
+   row. The leading dimension refers to the local array, and hence can be different
+   in different processes.
+
+   The user does not need to change this parameter. The default value is equal to the
+   number of local rows, but this value may be increased a little to guarantee alignment
+   (especially in the case of GPU storage).
+
+   Level: advanced
+
+.seealso: BVGetLeadingDimension()
+@*/
+PetscErrorCode BVSetLeadingDimension(BV bv,PetscInt ld)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(bv,BV_CLASSID,1);
+  PetscValidLogicalCollectiveInt(bv,ld,2);
+  PetscCheck((bv->n<0 && bv->N<0) || !bv->ops->create,PetscObjectComm((PetscObject)bv),PETSC_ERR_ORDER,"Must call BVSetLeadingDimension() before setting the BV type and sizes");
+  if (ld == PETSC_DEFAULT) bv->ld = 0;
+  else {
+    PetscCheck(ld>0,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of ld. Must be > 0");
+    bv->ld = ld;
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+   BVGetLeadingDimension - Returns the leading dimension of the BV.
+
+   Not Collective
+
+   Input Parameter:
+.  bv - the basis vectors
+
+   Output Parameter:
+.  ld - the leading dimension
+
+   Level: advanced
+
+   Notes:
+   The returned value may be different in different processes.
+
+   The leading dimension must be used when accessing the internal array via
+   BVGetArray() or BVGetArrayRead().
+
+.seealso: BVSetLeadingDimension(), BVGetArray(), BVGetArrayRead()
+@*/
+PetscErrorCode BVGetLeadingDimension(BV bv,PetscInt *ld)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(bv,BV_CLASSID,1);
+  PetscAssertPointer(ld,2);
+  *ld = bv->ld;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
