@@ -305,17 +305,18 @@ PetscErrorCode BVTraceQuadrature(BV Y,BV V,PetscInt L,PetscInt L_max,PetscScalar
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
+static PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
 {
   PetscInt       i,j,k,ml=S->k;
   PetscMPIInt    len;
   PetscScalar    *work,*B,*tempB,*sarray,*Q1,*Q2,*temp2,alpha=1.0,beta=0.0;
-  PetscBLASInt   l,m,n,lda,ldu,ldvt,lwork,info,ldb,ldc;
+  PetscBLASInt   l,m,n,lda,ldu,ldvt,lwork,info,ldb,ldc,lds;
 #if defined(PETSC_USE_COMPLEX)
   PetscReal      *rwork;
 #endif
 
   PetscFunctionBegin;
+  PetscCall(PetscBLASIntCast(S->ld,&lds));
   PetscCall(BVGetArray(S,&sarray));
   PetscCall(PetscMalloc6(ml*ml,&temp2,S->n*ml,&Q1,S->n*ml,&Q2,ml*ml,&B,ml*ml,&tempB,5*ml,&work));
 #if defined(PETSC_USE_COMPLEX)
@@ -330,7 +331,7 @@ PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscRea
     PetscCall(PetscBLASIntCast(S->n,&m));
     PetscCall(PetscBLASIntCast(ml,&l));
     n = l; lda = m; ldb = m; ldc = l;
-    if (!k) PetscCallBLAS("BLASgemm",BLASgemm_("C","N",&l,&n,&m,&alpha,sarray,&lda,sarray,&ldb,&beta,pA,&ldc));
+    if (!k) PetscCallBLAS("BLASgemm",BLASgemm_("C","N",&l,&n,&m,&alpha,sarray,&lds,sarray,&lds,&beta,pA,&ldc));
     else PetscCallBLAS("BLASgemm",BLASgemm_("C","N",&l,&n,&m,&alpha,Q1,&lda,Q1,&ldb,&beta,pA,&ldc));
     PetscCall(PetscArrayzero(temp2,ml*ml));
     PetscCall(PetscMPIIntCast(ml*ml,&len));
@@ -348,7 +349,7 @@ PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscRea
     PetscCall(PetscBLASIntCast(S->n,&l));
     PetscCall(PetscBLASIntCast(ml,&n));
     m = n; lda = l; ldb = m; ldc = l;
-    if (!k) PetscCallBLAS("BLASgemm",BLASgemm_("N","N",&l,&n,&m,&alpha,sarray,&lda,temp2,&ldb,&beta,Q1,&ldc));
+    if (!k) PetscCallBLAS("BLASgemm",BLASgemm_("N","N",&l,&n,&m,&alpha,sarray,&lds,temp2,&ldb,&beta,Q1,&ldc));
     else PetscCallBLAS("BLASgemm",BLASgemm_("N","N",&l,&n,&m,&alpha,Q1,&lda,temp2,&ldb,&beta,Q2,&ldc));
 
     PetscCall(PetscBLASIntCast(ml,&l));
@@ -375,9 +376,9 @@ PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscRea
 
   PetscCall(PetscBLASIntCast(S->n,&l));
   PetscCall(PetscBLASIntCast(ml,&n));
-  m = n; lda = l; ldb = m; ldc = l;
-  if (k%2) PetscCallBLAS("BLASgemm",BLASgemm_("N","T",&l,&n,&m,&alpha,Q1,&lda,B,&ldb,&beta,sarray,&ldc));
-  else PetscCallBLAS("BLASgemm",BLASgemm_("N","T",&l,&n,&m,&alpha,Q2,&lda,B,&ldb,&beta,sarray,&ldc));
+  m = n; lda = l; ldb = m;
+  if (k%2) PetscCallBLAS("BLASgemm",BLASgemm_("N","T",&l,&n,&m,&alpha,Q1,&lda,B,&ldb,&beta,sarray,&lds));
+  else PetscCallBLAS("BLASgemm",BLASgemm_("N","T",&l,&n,&m,&alpha,Q2,&lda,B,&ldb,&beta,sarray,&lds));
 
   PetscCall(PetscFPTrapPop());
   PetscCall(BVRestoreArray(S,&sarray));
@@ -395,7 +396,7 @@ PetscErrorCode BVSVDAndRank_Refine(BV S,PetscReal delta,PetscScalar *pA,PetscRea
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVSVDAndRank_QR(BV S,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
+static PetscErrorCode BVSVDAndRank_QR(BV S,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
 {
   PetscInt       i,n,ml=S->k;
   PetscBLASInt   m,lda,lwork,info;
@@ -407,7 +408,7 @@ PetscErrorCode BVSVDAndRank_QR(BV S,PetscReal delta,PetscScalar *pA,PetscReal *s
   PetscFunctionBegin;
   /* Compute QR factorizaton of S */
   PetscCall(BVGetSizes(S,NULL,&n,NULL));
-  n    = PetscMin(n,ml);
+  n = PetscMin(n,ml);
   PetscCall(BVSetActiveColumns(S,0,n));
   PetscCall(PetscArrayzero(pA,ml*n));
   PetscCall(MatCreateDense(PETSC_COMM_SELF,n,n,PETSC_DECIDE,PETSC_DECIDE,pA,&A));
@@ -443,7 +444,7 @@ PetscErrorCode BVSVDAndRank_QR(BV S,PetscReal delta,PetscScalar *pA,PetscReal *s
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode BVSVDAndRank_QR_CAA(BV S,PetscInt M,PetscInt L,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
+static PetscErrorCode BVSVDAndRank_QR_CAA(BV S,PetscInt M,PetscInt L,PetscReal delta,PetscScalar *pA,PetscReal *sigma,PetscInt *rank)
 {
   PetscInt       i,j,n,ml=S->k;
   PetscBLASInt   m,k_,lda,lwork,info;
@@ -541,9 +542,9 @@ PetscErrorCode BVSVDAndRank(BV S,PetscInt m,PetscInt l,PetscReal delta,BVSVDMeth
   PetscValidLogicalCollectiveInt(S,l,3);
   PetscValidLogicalCollectiveReal(S,delta,4);
   PetscValidLogicalCollectiveEnum(S,meth,5);
-  PetscValidScalarPointer(A,6);
-  PetscValidRealPointer(sigma,7);
-  PetscValidIntPointer(rank,8);
+  PetscAssertPointer(A,6);
+  PetscAssertPointer(sigma,7);
+  PetscAssertPointer(rank,8);
 
   PetscCall(PetscLogEventBegin(BV_SVDAndRank,S,0,0,0));
   PetscCall(BVSetActiveColumns(S,0,m*l));
