@@ -417,7 +417,7 @@ PetscErrorCode BVOrthonormalizeColumn(BV bv,PetscInt j,PetscBool replace,PetscRe
   if (nrm!=1.0 && nrm!=0.0) {
     alpha = 1.0/nrm;
     PetscCall(PetscLogEventBegin(BV_Scale,bv,0,0,0));
-    if (bv->n) PetscUseTypeMethod(bv,scale,j,alpha);
+    PetscUseTypeMethod(bv,scale,j,alpha);
     PetscCall(PetscLogEventEnd(BV_Scale,bv,0,0,0));
   }
   if (norm) *norm = nrm;
@@ -464,7 +464,7 @@ PetscErrorCode BVOrthogonalizeSomeColumn(BV bv,PetscInt j,PetscBool *which,Petsc
   PetscFunctionBegin;
   PetscValidHeaderSpecific(bv,BV_CLASSID,1);
   PetscValidLogicalCollectiveInt(bv,j,2);
-  PetscValidBoolPointer(which,3);
+  PetscAssertPointer(which,3);
   PetscValidType(bv,1);
   BVCheckSizes(bv,1);
   PetscCheck(j>=0,PetscObjectComm((PetscObject)bv),PETSC_ERR_ARG_OUTOFRANGE,"Index j must be non-negative");
@@ -625,7 +625,7 @@ static PetscErrorCode BVOrthogonalize_TSQR(BV V,Mat Rin)
   PetscCall(MatDenseGetLDA(R,&ldr));
   PetscCall(MatDenseGetArray(R,&r));
   PetscCall(BVGetArray(V,&pv));
-  PetscCall(BVOrthogonalize_LAPACK_TSQR(V,V->n,V->k-V->l,pv+(V->nc+V->l)*V->n,r+V->l*ldr+V->l,ldr));
+  PetscCall(BVOrthogonalize_LAPACK_TSQR(V,V->n,V->k-V->l,pv+(V->nc+V->l)*V->ld,V->ld,r+V->l*ldr+V->l,ldr));
   PetscCall(BVRestoreArray(V,&pv));
   PetscCall(MatDenseRestoreArray(R,&r));
   if (Rin) PetscCall(BV_StoreCoeffsBlock_Default(V,Rin,PETSC_TRUE));
@@ -650,7 +650,7 @@ static PetscErrorCode BVOrthogonalize_TSQRCHOL(BV V,Mat Rin)
   PetscCall(MatDenseGetLDA(R,&ldr));
   PetscCall(MatDenseGetArray(R,&r));
   PetscCall(BVGetArray(V,&pv));
-  PetscCall(BVOrthogonalize_LAPACK_TSQR_OnlyR(V,V->n,V->k-V->l,pv+(V->nc+V->l)*V->n,r+V->l*ldr+V->l,ldr));
+  PetscCall(BVOrthogonalize_LAPACK_TSQR_OnlyR(V,V->n,V->k-V->l,pv+(V->nc+V->l)*V->ld,V->ld,r+V->l*ldr+V->l,ldr));
   PetscCall(BVRestoreArray(V,&pv));
   PetscCall(MatDenseRestoreArray(R,&r));
   PetscCall(BVMatTriInv_LAPACK_Private(V,R,S));
