@@ -144,14 +144,14 @@ int main(int argc,char **argv)
          args: -bv_type {{vecs contiguous svec mat}shared output}
       test:
          suffix: 1_cuda
-         args: -bv_type svec -mat_type aijcusparse
+         args: -bv_type {{svec mat}} -mat_type aijcusparse
          requires: cuda
       test:
          suffix: 2
          args: -bv_type {{vecs contiguous svec mat}shared output} -bv_orthog_type mgs
       test:
          suffix: 2_cuda
-         args: -bv_type svec -mat_type aijcusparse -bv_orthog_type mgs
+         args: -bv_type {{svec mat}} -mat_type aijcusparse -bv_orthog_type mgs
          requires: cuda
 
 TEST*/
