@@ -104,7 +104,7 @@ int main(int argc,char **argv)
          args: -bv_type {{vecs contiguous svec mat}shared output}
       test:
          suffix: 1_cuda
-         args: -bv_type svec -vec_type cuda
+         args: -bv_type {{svec mat}} -vec_type cuda
          requires: cuda
       test:
          suffix: 2
@@ -118,7 +118,7 @@ int main(int argc,char **argv)
          args: -bv_type {{vecs contiguous svec mat}shared output} -bv_orthog_type mgs
       test:
          suffix: 4_cuda
-         args: -bv_type svec -vec_type cuda -bv_orthog_type mgs
+         args: -bv_type {{svec mat}} -vec_type cuda -bv_orthog_type mgs
          requires: cuda
 
 TEST*/
