@@ -60,7 +60,7 @@ static PetscErrorCode DSNEPComputeMatrix(DS ds,PetscScalar lambda,PetscBool deri
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSAllocate_NEP(DS ds,PetscInt ld)
+static PetscErrorCode DSAllocate_NEP(DS ds,PetscInt ld)
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
   PetscInt       i;
@@ -73,7 +73,7 @@ PetscErrorCode DSAllocate_NEP(DS ds,PetscInt ld)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSView_NEP(DS ds,PetscViewer viewer)
+static PetscErrorCode DSView_NEP(DS ds,PetscViewer viewer)
 {
   DS_NEP            *ctx = (DS_NEP*)ds->data;
   PetscViewerFormat format;
@@ -108,7 +108,7 @@ PetscErrorCode DSView_NEP(DS ds,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSVectors_NEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
+static PetscErrorCode DSVectors_NEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
 {
   PetscFunctionBegin;
   PetscCheck(!rnorm,PetscObjectComm((PetscObject)ds),PETSC_ERR_SUP,"Not implemented yet");
@@ -123,7 +123,7 @@ PetscErrorCode DSVectors_NEP(DS ds,DSMatType mat,PetscInt *j,PetscReal *rnorm)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSSort_NEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,PetscScalar *ri,PetscInt *dummy)
+static PetscErrorCode DSSort_NEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,PetscScalar *ri,PetscInt *dummy)
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
   PetscInt       n,l,i,*perm,lds;
@@ -148,39 +148,26 @@ PetscErrorCode DSSort_NEP(DS ds,PetscScalar *wr,PetscScalar *wi,PetscScalar *rr,
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
+#if defined(SLEPC_MISSING_LAPACK_GGEV3)
+#define LAPGEEV "ggev"
+#else
+#define LAPGEEV "ggev3"
+#endif
+
+static PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
-  PetscScalar    *A,*B,*W,*X,*work,*alpha,*beta;
+  PetscScalar    *A,*B,*W,*X,*work,*alpha,*beta,a;
   PetscScalar    sigma,lambda,mu,re,re2,sone=1.0,szero=0.0;
-  PetscBLASInt   info,n,ld,lrwork=0,lwork,one=1,zero=0;
+  PetscBLASInt   info,n,ld,lwork,one=1,zero=0;
   PetscInt       it,pos,j,maxit=100,result;
   PetscReal      norm,tol,done=1.0;
-#if defined(PETSC_USE_COMPLEX)
-  PetscReal      *rwork;
-#else
+#if !defined(PETSC_USE_COMPLEX)
   PetscReal      *alphai,im,im2;
 #endif
 
   PetscFunctionBegin;
   PetscCall(PetscBLASIntCast(ds->n,&n));
   PetscCall(PetscBLASIntCast(ds->ld,&ld));
-#if defined(PETSC_USE_COMPLEX)
-  PetscCall(PetscBLASIntCast(2*ds->n+2*ds->n,&lwork));
-  PetscCall(PetscBLASIntCast(8*ds->n,&lrwork));
-#else
-  PetscCall(PetscBLASIntCast(3*ds->n+8*ds->n,&lwork));
-#endif
-  PetscCall(DSAllocateWork_Private(ds,lwork,lrwork,0));
-  alpha = ds->work;
-  beta = ds->work + ds->n;
-#if defined(PETSC_USE_COMPLEX)
-  work = ds->work + 2*ds->n;
-  lwork -= 2*ds->n;
-#else
-  alphai = ds->work + 2*ds->n;
-  work = ds->work + 3*ds->n;
-  lwork -= 3*ds->n;
-#endif
   PetscCall(DSAllocateMat_Private(ds,DS_MAT_A));
   PetscCall(DSAllocateMat_Private(ds,DS_MAT_B));
   PetscCall(DSAllocateMat_Private(ds,DS_MAT_W));
@@ -189,6 +176,25 @@ PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
   PetscCall(MatDenseGetArray(ds->omat[DS_MAT_W],&W));
   PetscCall(MatDenseGetArray(ds->omat[DS_MAT_X],&X));
 
+  /* workspace query and memory allocation */
+  lwork = -1;
+#if defined(PETSC_USE_COMPLEX)
+  PetscCallBLAS("LAPACK" LAPGEEV,LAPACKggevalt_("N","V",&n,A,&ld,B,&ld,NULL,NULL,NULL,&ld,W,&ld,&a,&lwork,NULL,&info));
+  PetscCall(PetscBLASIntCast((PetscInt)PetscRealPart(a),&lwork));
+  PetscCall(DSAllocateWork_Private(ds,lwork+2*ds->n,8*ds->n,0));
+  alpha = ds->work;
+  beta  = ds->work + ds->n;
+  work  = ds->work + 2*ds->n;
+#else
+  PetscCallBLAS("LAPACK" LAPGEEV,LAPACKggevalt_("N","V",&n,A,&ld,B,&ld,NULL,NULL,NULL,NULL,&ld,W,&ld,&a,&lwork,&info));
+  PetscCall(PetscBLASIntCast((PetscInt)a,&lwork));
+  PetscCall(DSAllocateWork_Private(ds,lwork+3*ds->n,0,0));
+  alpha  = ds->work;
+  beta   = ds->work + ds->n;
+  alphai = ds->work + 2*ds->n;
+  work   = ds->work + 3*ds->n;
+#endif
+
   sigma = 0.0;
   if (ds->sc->comparison==SlepcCompareTargetMagnitude || ds->sc->comparison==SlepcCompareTargetReal) sigma = *(PetscScalar*)ds->sc->comparisonctx;
   lambda = sigma;
@@ -207,12 +213,11 @@ PetscErrorCode DSSolve_NEP_SLP(DS ds,PetscScalar *wr,PetscScalar *wi)
 
     /* compute eigenvalue correction mu and eigenvector u */
 #if defined(PETSC_USE_COMPLEX)
-    rwork = ds->rwork;
-    PetscCallBLAS("LAPACKggev",LAPACKggev_("N","V",&n,A,&ld,B,&ld,alpha,beta,NULL,&ld,W,&ld,work,&lwork,rwork,&info));
+    PetscCallBLAS("LAPACK" LAPGEEV,LAPACKggevalt_("N","V",&n,A,&ld,B,&ld,alpha,beta,NULL,&ld,W,&ld,work,&lwork,ds->rwork,&info));
 #else
-    PetscCallBLAS("LAPACKggev",LAPACKggev_("N","V",&n,A,&ld,B,&ld,alpha,alphai,beta,NULL,&ld,W,&ld,work,&lwork,&info));
+    PetscCallBLAS("LAPACK" LAPGEEV,LAPACKggevalt_("N","V",&n,A,&ld,B,&ld,alpha,alphai,beta,NULL,&ld,W,&ld,work,&lwork,&info));
 #endif
-    SlepcCheckLapackInfo("ggev",info);
+    SlepcCheckLapackInfo(LAPGEEV,info);
 
     /* find smallest eigenvalue */
     j = 0;
@@ -322,12 +327,10 @@ static PetscErrorCode DSNEPNewtonRefine(DS ds,PetscInt k,PetscScalar *wr)
           PetscCallBLAS("BLASgemv",BLASgemv_("N",&n,&n,&sone,W,&ld,X+ld*j,&one,&szero,U+n*(n+1),&one));
           PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_W],&W));
           /* solve system  */
-          PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
           PetscCallBLAS("LAPACKgetrf",LAPACKgetrf_(&n1,&n1,U,&n1,perm,&info));
           SlepcCheckLapackInfo("getrf",info);
           PetscCallBLAS("LAPACKgetrs",LAPACKgetrs_("N",&n1,&one,U,&n1,perm,R,&n1,&info));
           SlepcCheckLapackInfo("getrs",info);
-          PetscCall(PetscFPTrapPop());
           wr[j] -= R[n];
           for (i=0;i<n;i++) X[j*ld+i] -= R[i];
           /* normalization */
@@ -361,7 +364,7 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
   PetscScalar    *alpha,*beta,*Q,*Z,*X,*U,*V,*W,*work,*Rc,*R,*w,*z,*zn,*S;
-  PetscScalar    sone=1.0,szero=0.0,center;
+  PetscScalar    sone=1.0,szero=0.0,center,a;
   PetscReal      *rwork,norm,radius,vscale,rgscale,*sigma;
   PetscBLASInt   info,n,*perm,p,pp,ld,lwork,k_,rk_,colA,rowA,one=1;
   PetscInt       mid,lds,nnod=ctx->nnod,k,i,ii,jj,j,s,off,rk,nwu=0,nw,lrwork,*inside,kstart=0,kend=nnod;
@@ -395,10 +398,14 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
   p    = n;   /* maximum number of columns for the probing matrix */
   PetscCall(PetscBLASIntCast(ds->ld,&ld));
   PetscCall(PetscBLASIntCast(mid*n,&rowA));
-  PetscCall(PetscBLASIntCast(5*rowA,&lwork));
-  nw   = n*(2*p+7*mid)+3*nnod+2*mid*n*p;
-  lrwork = mid*n*6+8*n;
-  PetscCall(DSAllocateWork_Private(ds,nw,lrwork,n+1));
+  nw     = 2*n*(p+mid)+3*nnod+2*mid*n*p;
+  lrwork = 9*mid*n;
+
+  /* workspace query and memory allocation */
+  lwork = -1;
+  PetscCallBLAS("LAPACK" LAPGEEV,LAPACKggevalt_("N","V",&rowA,Q,&rowA,Z,&rowA,NULL,NULL,NULL,&ld,V,&rowA,&a,&lwork,NULL,&info));
+  PetscCall(PetscBLASIntCast((PetscInt)PetscRealPart(a),&lwork));
+  PetscCall(DSAllocateWork_Private(ds,lwork+nw,lrwork,n+1));
 
   sigma = ds->rwork;
   rwork = ds->rwork+mid*n;
@@ -411,7 +418,7 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
   alpha = ds->work+nwu;    nwu += mid*n;
   beta  = ds->work+nwu;    nwu += mid*n;
   S     = ds->work+nwu;    nwu += 2*mid*n*p;
-  work  = ds->work+nwu;    /*nwu += mid*n*5;*/
+  work  = ds->work+nwu;
 
   /* Compute quadrature parameters */
   PetscCall(RGComputeQuadrature(ctx->rg,RG_QUADRULE_TRAPEZOIDAL,nnod,z,zn,w));
@@ -431,12 +438,10 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
 
     /* LU factorization */
     PetscCall(MatDenseGetArray(ds->omat[DS_MAT_W],&W));
-    PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
     PetscCallBLAS("LAPACKgetrf",LAPACKgetrf_(&n,&n,W,&ld,perm,&info));
     SlepcCheckLapackInfo("getrf",info);
     PetscCallBLAS("LAPACKgetrs",LAPACKgetrs_("N",&n,&p,W,&ld,perm,R,&n,&info));
     SlepcCheckLapackInfo("getrs",info);
-    PetscCall(PetscFPTrapPop());
     PetscCall(MatDenseRestoreArray(ds->omat[DS_MAT_W],&W));
 
     /* Moments computation */
@@ -466,10 +471,8 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
           for (i=0;i<n;i++) Q[off+j*rowA+i] = S[((jj+ii)*n+j)*n+i];
       }
     }
-    PetscCall(PetscFPTrapPush(PETSC_FP_TRAP_OFF));
     PetscCallBLAS("LAPACKgesvd",LAPACKgesvd_("S","S",&rowA,&colA,Q,&rowA,sigma,U,&rowA,V,&colA,work,&lwork,rwork,&info));
     SlepcCheckLapackInfo("gesvd",info);
-    PetscCall(PetscFPTrapPop());
 
     rk = colA;
     for (i=1;i<colA;i++) if (sigma[i]/sigma[0]<PETSC_MACHINE_EPSILON*1e4) {rk = i; break;}
@@ -489,7 +492,8 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
   PetscCallBLAS("BLASgemm",BLASgemm_("C","N",&rk_,&rk_,&rowA,&sone,U,&rowA,Z,&rowA,&szero,Q,&rk_));
   PetscCall(PetscArrayzero(Z,n*mid*n*mid));
   for (j=0;j<rk;j++) Z[j+j*rk_] = sigma[j];
-  PetscCallBLAS("LAPACKggev",LAPACKggev_("N","V",&rk_,Q,&rk_,Z,&rk_,alpha,beta,NULL,&ld,V,&rk_,work,&lwork,rwork,&info));
+  PetscCallBLAS("LAPACK" LAPGEEV,LAPACKggevalt_("N","V",&rk_,Q,&rk_,Z,&rk_,alpha,beta,NULL,&ld,V,&rk_,work,&lwork,rwork,&info));
+  SlepcCheckLapackInfo(LAPGEEV,info);
   for (i=0;i<rk;i++) wr[i] = (center+radius*alpha[i]/beta[i])*rgscale;
   PetscCall(PetscMalloc1(rk,&inside));
   PetscCall(RGCheckInside(ctx->rg,rk,wr,wi,inside));
@@ -528,7 +532,7 @@ PetscErrorCode DSSolve_NEP_Contour(DS ds,PetscScalar *wr,PetscScalar *wi)
 #endif
 
 #if !defined(PETSC_HAVE_MPIUNI)
-PetscErrorCode DSSynchronize_NEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
+static PetscErrorCode DSSynchronize_NEP(DS ds,PetscScalar eigr[],PetscScalar eigi[])
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
   PetscInt       ld=ds->ld,k=0;
@@ -619,7 +623,7 @@ PetscErrorCode DSNEPSetFN(DS ds,PetscInt n,FN fn[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
   PetscValidLogicalCollectiveInt(ds,n,2);
-  PetscValidPointer(fn,3);
+  PetscAssertPointer(fn,3);
   for (i=0;i<n;i++) {
     PetscValidHeaderSpecific(fn[i],FN_CLASSID,3);
     PetscCheckSameComm(ds,1,fn[i],3);
@@ -658,7 +662,7 @@ PetscErrorCode DSNEPGetFN(DS ds,PetscInt k,FN *fn)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  PetscValidPointer(fn,3);
+  PetscAssertPointer(fn,3);
   PetscUseMethod(ds,"DSNEPGetFN_C",(DS,PetscInt,FN*),(ds,k,fn));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -692,7 +696,7 @@ PetscErrorCode DSNEPGetNumFN(DS ds,PetscInt *n)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  PetscValidIntPointer(n,2);
+  PetscAssertPointer(n,2);
   PetscUseMethod(ds,"DSNEPGetNumFN_C",(DS,PetscInt*),(ds,n));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -771,7 +775,7 @@ PetscErrorCode DSNEPGetMinimality(DS ds,PetscInt *n)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  PetscValidIntPointer(n,2);
+  PetscAssertPointer(n,2);
   PetscUseMethod(ds,"DSNEPGetMinimality_C",(DS,PetscInt*),(ds,n));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -934,7 +938,7 @@ PetscErrorCode DSNEPGetIntegrationPoints(DS ds,PetscInt *ip)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  PetscValidIntPointer(ip,2);
+  PetscAssertPointer(ip,2);
   PetscUseMethod(ds,"DSNEPGetIntegrationPoints_C",(DS,PetscInt*),(ds,ip));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1010,7 +1014,7 @@ PetscErrorCode DSNEPGetSamplingSize(DS ds,PetscInt *p)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  PetscValidIntPointer(p,2);
+  PetscAssertPointer(p,2);
   PetscUseMethod(ds,"DSNEPGetSamplingSize_C",(DS,PetscInt*),(ds,p));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -1170,12 +1174,12 @@ PetscErrorCode DSNEPGetRG(DS ds,RG *rg)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ds,DS_CLASSID,1);
-  PetscValidPointer(rg,2);
+  PetscAssertPointer(rg,2);
   PetscUseMethod(ds,"DSNEPGetRG_C",(DS,RG*),(ds,rg));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSSetFromOptions_NEP(DS ds,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode DSSetFromOptions_NEP(DS ds,PetscOptionItems *PetscOptionsObject)
 {
   PetscInt       k;
   PetscBool      flg;
@@ -1214,7 +1218,7 @@ PetscErrorCode DSSetFromOptions_NEP(DS ds,PetscOptionItems *PetscOptionsObject)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSDestroy_NEP(DS ds)
+static PetscErrorCode DSDestroy_NEP(DS ds)
 {
   DS_NEP         *ctx = (DS_NEP*)ds->data;
   PetscInt       i;
@@ -1242,7 +1246,7 @@ PetscErrorCode DSDestroy_NEP(DS ds)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode DSMatGetSize_NEP(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols)
+static PetscErrorCode DSMatGetSize_NEP(DS ds,DSMatType t,PetscInt *rows,PetscInt *cols)
 {
   DS_NEP *ctx = (DS_NEP*)ds->data;
 
