@@ -1,7 +1,7 @@
 !
 !  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 !  SLEPc - Scalable Library for Eigenvalue Problem Computations
-!  Copyright (c) 2002-2021, Universitat Politecnica de Valencia, Spain
+!  Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain
 !
 !  This file is part of SLEPc.
 !  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -22,3 +22,9 @@
       PetscEnum, parameter :: FN_COMBINE_DIVIDE        =  2
       PetscEnum, parameter :: FN_COMBINE_COMPOSE       =  3
 
+      PetscEnum, parameter :: FN_PARALLEL_REDUNDANT    =  0
+      PetscEnum, parameter :: FN_PARALLEL_SYNCHRONIZED =  1
+
+#if defined(_WIN32) && defined(PETSC_USE_SHARED_LIBRARIES)
+!DEC$ ATTRIBUTES DLLEXPORT::SLEPC_NULL_FN
+#endif
