@@ -88,7 +88,7 @@ static PetscErrorCode SlepcPrintVersion(MPI_Comm comm)
   PetscCall(SlepcGetVersion(version,256));
   PetscCall((*PetscHelpPrintf)(comm,"%s\n",version));
   PetscCall((*PetscHelpPrintf)(comm,SLEPC_AUTHOR_INFO));
-  PetscCall((*PetscHelpPrintf)(comm,"See docs/manual.html for help.\n"));
+  PetscCall((*PetscHelpPrintf)(comm,"See https://slepc.upv.es/documentation/ for help.\n"));
   PetscCall((*PetscHelpPrintf)(comm,"SLEPc libraries linked from %s\n",SLEPC_LIB_DIR));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
@@ -224,7 +224,7 @@ PetscErrorCode SlepcCitationsInitialize(void)
   PetscCall(PetscCitationsRegister("@TechReport{slepc-manual,\n"
     "   author = \"J. E. Roman and C. Campos and L. Dalcin and E. Romero and A. Tomas\",\n"
     "   title = \"{SLEPc} Users Manual\",\n"
-    "   number = \"DSIC-II/24/02 - Revision 3.19\",\n"
+    "   number = \"DSIC-II/24/02 - Revision 3.20\",\n"
     "   institution = \"D. Sistemes Inform\\`atics i Computaci\\'o, Universitat Polit\\`ecnica de Val\\`encia\",\n"
     "   year = \"2023\"\n"
     "}\n",NULL));
@@ -250,7 +250,7 @@ PetscErrorCode SlepcCitationsInitialize(void)
 
    Level: beginner
 
-.seealso: SlepcFinalize(), PetscInitialize()
+.seealso: SlepcFinalize(), PetscInitialize(), SlepcInitializeFortran()
 @*/
 PetscErrorCode SlepcInitialize(int *argc,char ***args,const char file[],const char help[])
 {
